import re
from copy import deepcopy

import requests_mock

# flake8: noqa: E501


def register_uris(adapter):
    """
    Register on an adapter:

    - a dump of https://forum.snapcraft.io/t/documentation-outline/3781.json
    from 2018-09-19 11:10
    - a dump of https://forum.snapcraft.io/t/getting-started/3876.json
    from 2018-09-19 11:25
    - a dump of https://forum.snapcraft.io/t/configuration-options/87.json (redirect)
    from 2018-09-20 12:13
    - A dump of https://forum.snapcraft.io/t/fictional-document.json (404)
    from 2018-09-20 12:00
    """

    # Register mock URIs
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/choosing-a-security-model/6847.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 31518,
                        "name": "Evan",
                        "username": "evan",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                        "created_at": "2018-08-13T12:06:34.962Z",
                        "cooked": '<aside class="quote no-group">\n<blockquote>\n<p><img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"> <strong>NOTE TO EDITORS</strong> <img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"></p>\n<p>This topic contributes to a new set of snap documentation. See <a href="/t/proposed-new-documentation-outline/6718">Proposed new documentation outline</a> for further details.</p>\n</blockquote>\n</aside>\n<p>Snaps are containerised to ensure more predictable application behaviour and greater security.</p>\n<p>Now that <a>testing your app</a> has proven it working outside of confinement, it’s time to turn confinement on so your app can be marked as “stable” when published in the Snap Store.</p>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ There are three classes of application that cannot meet the requirements of confinement. These are where the app needs to:</p>\n<ul>\n<li>Open arbitrary filesystem paths outside of <code>$HOME</code> and /media</li>\n<li>Run other programs that cannot be determined at build time</li>\n<li>Perform privileged tasks not yet covered by interfaces (below)</li>\n</ul>\n<p>In these cases, <a href="/t/snap-confinement/6233">“classic” confinement</a> may be an option.</p>\n</blockquote>\n</aside>\n<p>To confine your application, return to your snapcraft.yaml file and change the confinement value from <code>devmode</code> to <code>strict</code>:</p>\n<pre><code class="lang-yaml">confinement: strict\n</code></pre>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ If you are working with an Electron app, you will not have a snapcraft.yaml file. Set the <code>confinement</code> <a href="https://www.electron.build/configuration/snap">property</a>, under the top-level <code>snap</code> key in your package.json file. This defaults to <code>strict</code>.</p>\n</blockquote>\n</aside>\n<p>You will also likely need to specify some interfaces. These are declarations that tell the system to give permission for a specific task, such as accessing a webcam or binding to a network port. You can find a list of interfaces and their intended purpose in the <a href="https://forum.snapcraft.io/t/supported-interfaces/7744">reference documentation</a>.</p>\n<p>The interfaces are specified as a list of “<code>plugs</code>” in your snapcraft.yaml file, alongside your <code>command</code> definition. For example, if your application needs access to the Internet and to the user’s home directory:</p>\n<pre><code class="lang-yaml">apps:\n  offlineimap:\n    command: bin/offlineimap\n    plugs: [home, network]\n</code></pre>\n<p>If you have multiple <code>command</code> definitions, you will need to provide separate <code>plugs</code> definitions for each.</p>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ If you are working with an Electron app, you will not have a snapcraft.yaml file. Set the <code>plugs</code> <a href="https://www.electron.build/configuration/snap">property</a>, under the top-level <code>snap</code> key in your package.json file. Include <code>"default"</code> in this list to include the default interfaces.</p>\n</blockquote>\n</aside>\n<p>Now that your snapcraft.yaml is updated for confinement, <a href="/t/building-the-snap/6800">rebuild your snap</a>. This is a quick process when only the confinement method has changed.</p>\n<p><a>Install and test</a> your rebuilt snap. If your app continues to work as expected, you’re ready for publishing in the Snap Store.</p>\n<h3>Debugging</h3>\n<p>If your app has failed to start or behaves incorrectly, you may be missing some interfaces. Check <code>journalctl -xe</code> for a possible explanation, then refer to the interfaces in the <a href="https://forum.snapcraft.io/t/supported-interfaces/7744">reference documentation</a>. Add any missing interfaces to your <code>plugs</code> definition, rebuild your snap, and test again.</p>\n<p>If no explanation can be found, ask for assistance on the <a href="https://forum.snapcraft.io/c/snap">Snapcraft Forum</a>. Be sure to include any relevant details, such as the contents of log files and any error messages printed on the terminal.</p>\n<h3>Next steps</h3>\n<p>Continue on to learn how to <a href="/t/releasing-to-the-snap-store/6848">release your app in the Snap Store</a>.</p>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2019-03-27T09:47:20.897Z",
                        "reply_count": 2,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 41,
                        "incoming_link_count": 22,
                        "reads": 29,
                        "score": 127.65,
                        "yours": False,
                        "topic_id": 6847,
                        "topic_slug": "choosing-a-security-model",
                        "display_username": "Evan",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 7,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/building-the-snap/6800",
                                "internal": True,
                                "reflection": False,
                                "title": "Building the snap",
                                "clicks": 2,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/supported-interfaces/7744",
                                "internal": True,
                                "reflection": False,
                                "title": "Supported interfaces",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/c/snap",
                                "internal": True,
                                "reflection": False,
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/releasing-to-the-snap-store/6848",
                                "internal": True,
                                "reflection": True,
                                "title": "Releasing to the Snap Store",
                                "clicks": 3,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/proposed-new-documentation-outline/6718",
                                "internal": True,
                                "reflection": True,
                                "title": "Proposed new documentation outline",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/creating-your-developer-account/6760",
                                "internal": True,
                                "reflection": True,
                                "title": "Creating your developer account",
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 12,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": "removing non-working link",
                        "can_view_edit_history": True,
                        "wiki": True,
                        "last_wiki_edit": "2019-03-27T09:47:20.966Z",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 31533,
                        "name": "Samuele Pedroni",
                        "username": "pedronis",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/pedronis/{size}/46_1.png",
                        "created_at": "2018-08-13T15:11:30.685Z",
                        "cooked": '<p><a class="mention" href="/u/jdstrand">@jdstrand</a> this is a doc topic you might have further input on</p>',
                        "post_number": 2,
                        "post_type": 1,
                        "updated_at": "2018-08-13T15:11:30.685Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 16,
                        "incoming_link_count": 0,
                        "reads": 25,
                        "score": 7.6,
                        "yours": False,
                        "topic_id": 6847,
                        "topic_slug": "choosing-a-security-model",
                        "display_username": "Samuele Pedroni",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 13,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 32036,
                        "name": "林博仁(Buo-ren, Lin)",
                        "username": "Lin-Buo-Ren",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                        "created_at": "2018-08-21T01:20:07.312Z",
                        "cooked": '<aside class="quote no-group" data-post="1" data-topic="6847">\n<div class="title">\n<div class="quote-controls"></div>\n<img alt width="20" height="20" src="https://forum.snapcraft.io/user_avatar/forum.snapcraft.io/evan/40/28_1.png" class="avatar"> evan:</div>\n<blockquote>\n<p><code>/var/log/system</code></p>\n</blockquote>\n</aside>\n<p>Note that this path is not available in Debian-derived distros (<code>/var/log/syslog</code>), maybe using the <code>journalctl</code> command is more appropriate.</p>',
                        "post_number": 3,
                        "post_type": 1,
                        "updated_at": "2018-08-21T01:20:07.312Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 1,
                        "avg_time": 12,
                        "incoming_link_count": 0,
                        "reads": 21,
                        "score": 9.6,
                        "yours": False,
                        "topic_id": 6847,
                        "topic_slug": "choosing-a-security-model",
                        "display_username": "林博仁(Buo-ren, Lin)",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": "Regular",
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 1417,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 32110,
                        "name": "Evan",
                        "username": "evan",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                        "created_at": "2018-08-22T11:56:53.860Z",
                        "cooked": '<p>Thanks <a class="mention" href="/u/lin-buo-ren">@Lin-Buo-Ren</a>, fixed.</p>',
                        "post_number": 4,
                        "post_type": 1,
                        "updated_at": "2018-08-22T11:56:53.860Z",
                        "reply_count": 0,
                        "reply_to_post_number": 3,
                        "quote_count": 0,
                        "avg_time": 9,
                        "incoming_link_count": 0,
                        "reads": 14,
                        "score": 18.05,
                        "yours": False,
                        "topic_id": 6847,
                        "topic_slug": "choosing-a-security-model",
                        "display_username": "Evan",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "Lin-Buo-Ren",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                        },
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 12,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 38414,
                        "name": "",
                        "username": "galgalesh",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/galgalesh/{size}/852_1.png",
                        "created_at": "2018-11-23T17:16:00.672Z",
                        "cooked": '<aside class="quote no-group" data-post="1" data-topic="6847">\n<div class="title">\n<div class="quote-controls"></div>\n<img alt width="20" height="20" src="https://forum.snapcraft.io/user_avatar/forum.snapcraft.io/evan/40/28_1.png" class="avatar"> evan:</div>\n<blockquote>\n<p>If your app has failed to start or behaves incorrectly, you may be missing some interfaces. Check <code>journalctl -xe</code> for a possible explanation, then refer to the interfaces in the reference documentation. Add any missing interfaces to your <code>plugs</code> definition, rebuild your snap, and test again.</p>\n</blockquote>\n</aside>\n<p>Maybe it’s best to also talk about <code>snappy-debug.security scanlog</code> instead of  only <code>journalctl -xe</code>, since <code>scanlog</code> actually gives you hints about which interfaces or actions can fix security violations. <code>scanlog</code> is currently explained in the “Identifying missing interfaces” part of the “debugging building snaps” docs: <a href="https://docs.snapcraft.io/debugging-building-snaps/6274" rel="nofollow noopener">https://docs.snapcraft.io/debugging-building-snaps/6274</a></p>',
                        "post_number": 5,
                        "post_type": 1,
                        "updated_at": "2018-11-23T17:16:19.869Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 1,
                        "avg_time": 38,
                        "incoming_link_count": 0,
                        "reads": 8,
                        "score": 18.3,
                        "yours": False,
                        "topic_id": 6847,
                        "topic_slug": "choosing-a-security-model",
                        "display_username": "",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://docs.snapcraft.io/debugging-building-snaps/6274",
                                "internal": False,
                                "reflection": False,
                                "title": "Debugging Building Snaps - Documentation for snaps: Universal Linux packages",
                                "clicks": 0,
                            }
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 1418,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                ],
                "stream": [31518, 31533, 32036, 32110, 38414],
            },
            "timeline_lookup": [[1, 227], [3, 219], [4, 218], [5, 124]],
            "suggested_topics": [
                {
                    "id": 6741,
                    "title": "Python apps",
                    "fancy_title": "Python apps",
                    "slug": "python-apps",
                    "posts_count": 14,
                    "reply_count": 6,
                    "highest_post_number": 14,
                    "image_url": None,
                    "created_at": "2018-08-08T15:48:27.631Z",
                    "last_posted_at": "2019-03-26T12:33:41.312Z",
                    "bumped": True,
                    "bumped_at": "2019-03-26T12:33:41.312Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 5,
                    "views": 2644,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 12,
                                "username": "evan",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 95,
                                "username": "sparkiegeek",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sparkiegeek/{size}/1397_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 1418,
                                "username": "galgalesh",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/galgalesh/{size}/852_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 285,
                                "username": "Odd_Bloke",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/odd_bloke/{size}/194_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 4404,
                                "username": "gandroz",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/gandroz/{size}/3023_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6747,
                    "title": "Node apps",
                    "fancy_title": "Node apps",
                    "slug": "node-apps",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-08T19:07:35.924Z",
                    "last_posted_at": "2018-08-08T19:07:36.098Z",
                    "bumped": True,
                    "bumped_at": "2018-11-23T11:35:25.827Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 1886,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 12,
                                "username": "evan",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 7823,
                    "title": "ROS2 applications",
                    "fancy_title": "ROS2 applications",
                    "slug": "ros2-applications",
                    "posts_count": 2,
                    "reply_count": 0,
                    "highest_post_number": 2,
                    "image_url": None,
                    "created_at": "2018-10-11T10:56:13.445Z",
                    "last_posted_at": "2018-10-11T10:56:32.474Z",
                    "bumped": True,
                    "bumped_at": "2018-10-11T10:56:32.474Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 1316,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 898,
                                "username": "nottrobin",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                            },
                        }
                    ],
                },
                {
                    "id": 7864,
                    "title": "The lxd-support interface",
                    "fancy_title": "The lxd-support interface",
                    "slug": "the-lxd-support-interface",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-10-11T17:06:46.900Z",
                    "last_posted_at": "2018-10-11T17:06:47.364Z",
                    "bumped": True,
                    "bumped_at": "2018-10-11T17:06:47.364Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 358,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 7896,
                    "title": "The openvswitch interface",
                    "fancy_title": "The openvswitch interface",
                    "slug": "the-openvswitch-interface",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-10-12T11:41:52.734Z",
                    "last_posted_at": "2018-10-12T11:41:53.161Z",
                    "bumped": True,
                    "bumped_at": "2019-01-30T17:24:56.702Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 303,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 6847,
            "title": "Choosing a security model",
            "fancy_title": "Choosing a security model",
            "posts_count": 5,
            "created_at": "2018-08-13T12:06:34.784Z",
            "views": 583,
            "reply_count": 1,
            "like_count": 3,
            "last_posted_at": "2018-11-23T17:16:00.672Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "choosing-a-security-model",
            "category_id": 15,
            "word_count": 701,
            "deleted_at": None,
            "user_id": 12,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": None,
            "pinned_until": None,
            "draft": None,
            "draft_key": "topic_6847",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": False,
            "details": {
                "created_by": {
                    "id": 12,
                    "username": "evan",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                },
                "last_poster": {
                    "id": 1418,
                    "username": "galgalesh",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/galgalesh/{size}/852_1.png",
                },
                "participants": [
                    {
                        "id": 12,
                        "username": "evan",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 13,
                        "username": "pedronis",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/pedronis/{size}/46_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1417,
                        "username": "Lin-Buo-Ren",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1418,
                        "username": "galgalesh",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/galgalesh/{size}/852_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/releasing-to-the-snap-store/6848",
                        "title": "Releasing to the Snap Store",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 3,
                        "user_id": 12,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/building-the-snap/6800",
                        "title": "Building the snap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 2,
                        "user_id": 12,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://docs.snapcraft.io/debugging-building-snaps/6274",
                        "title": "Debugging Building Snaps - Documentation for snaps: Universal Linux packages",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1418,
                        "domain": "docs.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/proposed-new-documentation-outline/6718",
                        "title": "Proposed new documentation outline",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 2772,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/supported-interfaces/7744",
                        "title": "Supported interfaces",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 12,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/creating-your-developer-account/6760",
                        "title": "Creating your developer account",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 12,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/c/snap",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 12,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 5,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 350,
            "participant_count": 4,
        },
        status_code=200,
        headers={
            "Date": "Thu, 28 Mar 2019 17:02:21 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "0708ddc2-eeab-4660-a1fc-a9eaa5556ae4",
            "X-Runtime": "0.312979",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/service-management/3965.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 19630,
                        "name": "Wiki Content",
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "created_at": "2018-02-11T23:01:06.680Z",
                        "cooked": '<aside class="quote no-group">\n<blockquote>\n<p><img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"> <strong>NOTE TO EDITORS</strong> <img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"></p>\n<p>This document is introductory material, and as such it is organized with a story line in mind. Each section builds upon information described in preceding sections. That also means the content is focused on foundational concepts, so it’s not a complete reference and not supposed to provide in-depth information about these aspects.</p>\n</blockquote>\n</aside>\n<p>The majority of snaps expose their functionality via applications that run on the local system. Most of these applications are started either from <a href="/t/commands-and-aliases/3950">the command line</a>, the graphical desktop, or as services that run automatically.</p>\n<p>A single snap may provide multiple applications and services. With a database snap, for example, you might expect an interactive client application alongside the service daemon.</p>\n<p>Snaps manage their own services without the need for manual intervention. However, experienced administrators may want to interact with a snap’s services to help improve their integration with the local environment. For that reason, snapd offers a set of commands to allow a snap’s services to be inspected and their statuses changed.</p>\n<h2>Listing services</h2>\n<p>Use <code>snap services</code> to lists all the services added to the system by the currently installed and enabled snaps. Adding a snap name as an argument will list only those services added by that snap:</p>\n<pre><code class="lang-bash">$ sudo snap services lxd\nService     Startup  Current\nlxd.daemon  enabled  active\n</code></pre>\n<p>The output includes the service name, whether the service is started when the system starts up, and whether it’s currently running.</p>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ Before snapd 2.32, the service name was split in two different columns, Snap and Service, but the service name was incorrectly reported as its suffix only.</p>\n</blockquote>\n</aside>\n<h2>Restarting services</h2>\n<p>Services are restarted using the <code>snap restart &lt;snap name&gt;</code> command. This may be necessary if you’ve made custom changes to the snap application, for example, which the service needs to reload.</p>\n<p>By default, all services for a specified snap will be restarted:</p>\n<pre><code class="lang-bash">$ sudo snap restart lxd\nRestarted.\n</code></pre>\n<p>Using a more specific service name performs the same operation on an individual service:</p>\n<pre><code class="lang-bash">$ sudo snap restart lxd.daemon\nRestarted.\n</code></pre>\n<p>The option to perform an operation on all of a snap’s services, or on one specific service, is common to all commands that operate on services.</p>\n<h2>Starting and stopping services</h2>\n<p>The <code>start</code> and <code>stop</code> commands control whether a service should be currently running:</p>\n<pre><code class="lang-bash">$ sudo snap stop lxd.daemon\nStopped.\n\n$ sudo snap start lxd.daemon\nStarted.\n</code></pre>\n<p>As mentioned above, these commands can operate both on individual snap’s services and on all services for a named snap, depending on the parameter provided.</p>\n<aside class="quote no-group">\n<blockquote>\n<p><img src="https://forum.snapcraft.io/images/emoji/emoji_one/warning.png?v=5" title=":warning:" class="emoji" alt=":warning:"> Stopping snap services manually may cause the snap to malfunction. For temporarily disabling a snap consider using the <em>enable</em> and <em>disable</em> commands instead.</p>\n</blockquote>\n</aside>\n<p>To prevent a service from starting on the next boot, use the <code>--disable</code> option:</p>\n<pre><code class="lang-bash">$ sudo snap stop --disable lxd.daemon\n</code></pre>\n<p>The <em>start</em> command includes an <code>--enable</code> option to re-enable the automatic starting of a service  when the system boots:</p>\n<pre><code class="lang-bash">$ sudo snap start --enable lxd.daemon\n</code></pre>\n<h2>Inspecting logs</h2>\n<p>If you need to see the log output for a snap’s services, use the <code>logs</code> command:</p>\n<pre><code class="lang-bash">$ snap logs lxd\n2018-09-14T10:38:23Z lxd.daemon[11096]: =&gt; LXD is ready\n(...)\n\n$ snap logs lxd.daemon\n(...)\n</code></pre>\n<p>Adding the <code>-f</code> option will keep log output  open so you can follow new entries as they occur:</p>\n<pre><code class="lang-bash">$ sudo snap logs lxd -f\n</code></pre>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2018-10-02T12:45:44.259Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 46,
                        "incoming_link_count": 73,
                        "reads": 52,
                        "score": 369.7,
                        "yours": False,
                        "topic_id": 3965,
                        "topic_slug": "service-management",
                        "display_username": "Wiki Content",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 10,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                                "internal": True,
                                "reflection": False,
                                "title": "Commands and aliases",
                                "clicks": 5,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/parallel-installs/7679",
                                "internal": True,
                                "reflection": True,
                                "title": "Parallel Installs",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/getting-started/3876",
                                "internal": True,
                                "reflection": True,
                                "title": "Getting started",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/snap-documentation/3781",
                                "internal": True,
                                "reflection": True,
                                "title": "Snap Documentation",
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 1044,
                        "hidden": False,
                        "trust_level": 1,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": True,
                        "last_wiki_edit": "2018-10-02T12:45:44.310Z",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    }
                ],
                "stream": [19630],
            },
            "timeline_lookup": [[1, 409]],
            "suggested_topics": [
                {
                    "id": 8405,
                    "title": "Deprecation notice: 5",
                    "fancy_title": "Deprecation notice: 5",
                    "slug": "deprecation-notice-5",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-11-08T17:42:07.028Z",
                    "last_posted_at": "2018-11-08T17:42:07.361Z",
                    "bumped": True,
                    "bumped_at": "2018-11-08T17:42:07.361Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 172,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 6755,
                    "title": "Installing snap on Fedora",
                    "fancy_title": "Installing snap on Fedora",
                    "slug": "installing-snap-on-fedora",
                    "posts_count": 15,
                    "reply_count": 10,
                    "highest_post_number": 15,
                    "image_url": None,
                    "created_at": "2018-08-09T10:52:09.815Z",
                    "last_posted_at": "2019-03-15T16:18:33.210Z",
                    "bumped": True,
                    "bumped_at": "2019-03-15T16:18:33.210Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 7,
                    "views": 3753,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 65,
                                "username": "sabdfl",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sabdfl/{size}/89_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 3715,
                                "username": "sstewartgallus",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/s/9fc348/{size}.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 3965,
                                "username": "leinad",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/l/67e7ee/{size}.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 4345,
                                "username": "orcainbox",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/orcainbox/{size}/2970_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 7901,
                    "title": "The physical-memory-observe interface",
                    "fancy_title": "The physical-memory-observe interface",
                    "slug": "the-physical-memory-observe-interface",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-10-12T12:39:17.665Z",
                    "last_posted_at": "2018-10-12T12:39:18.105Z",
                    "bumped": True,
                    "bumped_at": "2019-01-30T17:41:10.431Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 309,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 7873,
                    "title": "The media-hub interface",
                    "fancy_title": "The media-hub interface",
                    "slug": "the-media-hub-interface",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-10-12T09:16:52.461Z",
                    "last_posted_at": "2018-10-12T09:16:52.808Z",
                    "bumped": True,
                    "bumped_at": "2019-01-30T17:14:44.827Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 324,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 8629,
                    "title": "The scons plugin",
                    "fancy_title": "The scons plugin",
                    "slug": "the-scons-plugin",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-11-21T16:05:43.947Z",
                    "last_posted_at": "2018-11-21T16:05:44.282Z",
                    "bumped": True,
                    "bumped_at": "2018-11-21T16:05:44.282Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 192,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 3965,
            "title": "Service management",
            "fancy_title": "Service management",
            "posts_count": 1,
            "created_at": "2018-02-11T23:01:06.522Z",
            "views": 2831,
            "reply_count": 0,
            "like_count": 0,
            "last_posted_at": "2018-02-11T23:01:06.680Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "service-management",
            "category_id": 15,
            "word_count": 573,
            "deleted_at": None,
            "user_id": 1044,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": None,
            "pinned_until": None,
            "draft": None,
            "draft_key": "topic_3965",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": False,
            "details": {
                "created_by": {
                    "id": 1044,
                    "username": "wiki",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                },
                "last_poster": {
                    "id": 1044,
                    "username": "wiki",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                },
                "participants": [
                    {
                        "id": 1044,
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    }
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                        "title": "Commands and aliases",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 5,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/getting-started/3876",
                        "title": "Getting started",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/parallel-installs/7679",
                        "title": "Parallel Installs",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1497,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/snap-documentation/3781",
                        "title": "Snap Documentation",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 2772,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 1,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 24,
            "participant_count": 1,
        },
        status_code=200,
        headers={
            "Date": "Thu, 28 Mar 2019 17:10:30 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "5dbf1803-ec8c-4f0a-8e91-c74c12a83a8a",
            "X-Runtime": "0.672538",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    ),
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/script-to-remove-expired-kerberos-caches-for-enhanced-stability/10096.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 43489,
                        "name": "steve",
                        "username": "liveunix",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/l/85f322/{size}.png",
                        "created_at": "2019-02-22T07:05:29.722Z",
                        "cooked": "<p>I am getting below error msg.</p>\n<p><strong>/bin/krb5ccleaner.sh[3]: 22025 Segmentation Fault(coredump)</strong></p>",
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2019-02-22T07:05:29.722Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": None,
                        "incoming_link_count": 0,
                        "reads": 6,
                        "score": 1.0,
                        "yours": False,
                        "topic_id": 10096,
                        "topic_slug": "script-to-remove-expired-kerberos-caches-for-enhanced-stability",
                        "display_username": "steve",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 4214,
                        "hidden": False,
                        "trust_level": 0,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    }
                ],
                "stream": [43489],
            },
            "timeline_lookup": [[1, 0]],
            "suggested_topics": [
                {
                    "id": 6603,
                    "title": "Build.snapcraft.io for private projects",
                    "fancy_title": "Build.snapcraft.io for private projects",
                    "slug": "build-snapcraft-io-for-private-projects",
                    "posts_count": 3,
                    "reply_count": 0,
                    "highest_post_number": 3,
                    "image_url": None,
                    "created_at": "2018-07-29T22:15:57.331Z",
                    "last_posted_at": "2019-01-16T09:37:16.096Z",
                    "bumped": True,
                    "bumped_at": "2019-01-16T09:37:16.096Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 224,
                    "category_id": 1,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 797,
                                "username": "om26er",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/om26er/{size}/1067_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 9,
                                "username": "ogra",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ogra/{size}/22_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6865,
                    "title": "How to locate application locations?",
                    "fancy_title": "How to locate application locations?",
                    "slug": "how-to-locate-application-locations",
                    "posts_count": 3,
                    "reply_count": 0,
                    "highest_post_number": 3,
                    "image_url": None,
                    "created_at": "2018-08-14T06:14:33.917Z",
                    "last_posted_at": "2018-08-14T10:11:24.969Z",
                    "bumped": True,
                    "bumped_at": "2018-08-14T10:11:24.969Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 176,
                    "category_id": 1,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 2951,
                                "username": "e_ping",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/e/858c86/{size}.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 2453,
                                "username": "Zoralab",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/zoralab/{size}/1817_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 3,
                                "username": "chipaca",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/chipaca/{size}/37_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 5707,
                    "title": "Can't register snap",
                    "fancy_title": "Can&rsquo;t register snap",
                    "slug": "cant-register-snap",
                    "posts_count": 9,
                    "reply_count": 3,
                    "highest_post_number": 9,
                    "image_url": "https://avatars1.githubusercontent.com/u/494526?v=2&s=96",
                    "created_at": "2018-05-31T19:39:50.685Z",
                    "last_posted_at": "2018-06-04T17:11:07.185Z",
                    "bumped": True,
                    "bumped_at": "2018-06-04T17:11:07.185Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 256,
                    "category_id": 1,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2514,
                                "username": "superm1",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/superm1/{size}/1837_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 33,
                                "username": "roadmr",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/roadmr/{size}/52_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 14,
                                "username": "popey",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/popey/{size}/29_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 5290,
                    "title": "LibreOffice does not open",
                    "fancy_title": "LibreOffice does not open",
                    "slug": "libreoffice-does-not-open",
                    "posts_count": 4,
                    "reply_count": 0,
                    "highest_post_number": 4,
                    "image_url": None,
                    "created_at": "2018-05-04T20:01:07.396Z",
                    "last_posted_at": "2018-05-05T15:00:39.744Z",
                    "bumped": True,
                    "bumped_at": "2018-05-05T15:00:39.744Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 322,
                    "category_id": 1,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2278,
                                "username": "emanuc",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/e/ed655f/{size}.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 1600,
                                "username": "mcphail",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/m/e68b1a/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 7045,
                    "title": "Will there be a gnome-30-1804?",
                    "fancy_title": "Will there be a gnome-30-1804?",
                    "slug": "will-there-be-a-gnome-30-1804",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-25T05:32:46.109Z",
                    "last_posted_at": "2018-08-25T05:32:46.377Z",
                    "bumped": True,
                    "bumped_at": "2018-08-25T05:32:46.377Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 154,
                    "category_id": 1,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 1658,
                                "username": "jor1196",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/j/47e85d/{size}.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 10096,
            "title": "Script to remove expired Kerberos caches for enhanced stability",
            "fancy_title": "Script to remove expired Kerberos caches for enhanced stability",
            "posts_count": 1,
            "created_at": "2019-02-22T07:05:29.443Z",
            "views": 12,
            "reply_count": 0,
            "like_count": 0,
            "last_posted_at": "2019-02-22T07:05:29.722Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "script-to-remove-expired-kerberos-caches-for-enhanced-stability",
            "category_id": 1,
            "word_count": 14,
            "deleted_at": None,
            "user_id": 4214,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": None,
            "pinned_until": None,
            "draft": None,
            "draft_key": "topic_10096",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": False,
            "details": {
                "created_by": {
                    "id": 4214,
                    "username": "liveunix",
                    "avatar_template": "/letter_avatar_proxy/v2/letter/l/85f322/{size}.png",
                },
                "last_poster": {
                    "id": 4214,
                    "username": "liveunix",
                    "avatar_template": "/letter_avatar_proxy/v2/letter/l/85f322/{size}.png",
                },
                "participants": [
                    {
                        "id": 4214,
                        "username": "liveunix",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/l/85f322/{size}.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    }
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 1,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 4,
            "participant_count": 1,
        },
        status_code=200,
        headers={
            "Date": "Fri, 22 Feb 2019 11:55:45 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "c503911f-f800-4fca-be5f-ffe880b0ac14",
            "X-Runtime": "0.266571",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/documentation-outline/3781.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 18694,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-01-31T01:35:55.952Z",
                        "cooked": '<p>This is the experimental snap, snapd, and snapcraft documentation that is being worked on to eventually become the main source of information about how to use and publish snaps, and how to develop the tools around them.</p>\n<p>Most of this documentation can be collaboratively discussed and changed in the respective topic in the forum. See the <a href="/t/documentation-guidelines/3798">documentation guidelines</a> if you’d like to contribute.</p>\n<p>Choose the topic you’d like to read about.</p>\n<h1>Content</h1>\n<h3>Using</h3>\n<ul>\n<li><a href="/t/getting-started/3876">Getting started</a></li>\n<li><a href="/t/channels/551">Channels</a></li>\n<li><a href="/t/commands-and-aliases/3950">Commands and aliases</a></li>\n<li><a href="/t/service-management/3965">Service management</a></li>\n<li><a href="/t/configuration-in-snaps/510">Configuration in snaps</a></li>\n<li><a href="/t/system-options/87">System options</a></li>\n<li><a href="/t/the-snap-directory/2817">The /snap directory</a></li>\n<li><a href="/t/enabling-swap-on-ubuntu-core/5440">Enabling swap on Ubuntu Core</a></li>\n<li><a href="/t/5464">Ubuntu Core boot mode explained</a></li>\n</ul>\n\n<h3>Publishing</h3>\n<ul>\n<li><a href="/t/the-snap-format/698">The snap format</a></li>\n<li><a href="/t/the-gadget-snap/696">The gadget snap</a></li>\n<li><a href="/t/the-kernel-snap/697">The kernel snap</a></li>\n<li><a href="/t/the-content-interface/1074">The content interface</a></li>\n<li><a href="/t/the-dbus-interface/2038">The dbus interface</a></li>\n<li><a href="/t/the-desktop-interfaces/2042">The desktop interfaces</a></li>\n<li><a href="/t/supported-snap-hooks/3795">Supported hooks</a></li>\n<li><a href="/t/process-for-aliases-auto-connections-and-tracks/455">Permission requests</a></li>\n<li><a href="/t/tab-completion-for-snaps/2261">Tab completion</a></li>\n<li><a href="/t/clean-build-using-lxc/4157">Building with LXD</a></li>\n<li><a href="/t/build-on-docker/4158">Building with Docker</a></li>\n<li><a href="/t/remote-reusable-parts/4233">Building reusable parts</a></li>\n<li>\n<a href="/t/snapcraft-plugins/4284">Snapcraft plugins</a>\n<ul>\n<li><a href="/t/the-maven-plugin/4282">Maven</a></li>\n<li><a href="/t/gradle-plugin/5390">Gradle</a></li>\n</ul>\n</li>\n</ul>\n\n<h3>Developing</h3>\n<ul>\n<li><a href="/t/the-snapd-roadmap/1973">Roadmap</a></li>\n<li><a href="/t/documentation-guidelines/3798">Documentation guidelines</a></li>\n</ul>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2018-09-14T12:26:06.298Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 40,
                        "incoming_link_count": 140,
                        "reads": 65,
                        "score": 744.0,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 32,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/getting-started/3876",
                                "internal": True,
                                "reflection": False,
                                "title": "Getting started",
                                "clicks": 79,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snap-format/698",
                                "internal": True,
                                "reflection": False,
                                "title": "The snap format",
                                "clicks": 22,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                                "internal": True,
                                "reflection": False,
                                "title": "Commands and aliases",
                                "clicks": 18,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/documentation-guidelines/3798",
                                "internal": True,
                                "reflection": False,
                                "title": "Documentation guidelines",
                                "clicks": 17,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snap-directory/2817",
                                "internal": True,
                                "reflection": False,
                                "title": "The /snap directory",
                                "clicks": 17,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                                "internal": True,
                                "reflection": False,
                                "title": "Configuration in snaps",
                                "clicks": 15,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/service-management/3965",
                                "internal": True,
                                "reflection": False,
                                "title": "Service management",
                                "clicks": 14,
                            },
                            {
                                "url": "/t/5464",
                                "internal": True,
                                "reflection": False,
                                "clicks": 13,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/channels/551",
                                "internal": True,
                                "reflection": False,
                                "title": "Channels",
                                "clicks": 13,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-gadget-snap/696",
                                "internal": True,
                                "reflection": False,
                                "title": "The gadget snap",
                                "clicks": 10,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-kernel-snap/697",
                                "internal": True,
                                "reflection": False,
                                "title": "The kernel snap",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snapd-roadmap/1973",
                                "internal": True,
                                "reflection": False,
                                "title": "The snapd roadmap",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/clean-build-using-lxc/4157",
                                "internal": True,
                                "reflection": False,
                                "title": "Clean build - using LXC",
                                "clicks": 6,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/supported-snap-hooks/3795",
                                "internal": True,
                                "reflection": False,
                                "title": "Supported snap hooks",
                                "clicks": 6,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-dbus-interface/2038",
                                "internal": True,
                                "reflection": False,
                                "title": "The dbus interface",
                                "clicks": 5,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-desktop-interfaces/2042",
                                "internal": True,
                                "reflection": False,
                                "title": "The desktop interfaces",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-content-interface/1074",
                                "internal": True,
                                "reflection": False,
                                "title": "The content interface",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/build-on-docker/4158",
                                "internal": True,
                                "reflection": False,
                                "title": "Build on Docker",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/remote-reusable-parts/4233",
                                "internal": True,
                                "reflection": False,
                                "title": "Remote (reusable) parts",
                                "clicks": 2,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/snapcraft-plugins/4284",
                                "internal": True,
                                "reflection": False,
                                "title": "Snapcraft Plugins",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/gradle-plugin/5390",
                                "internal": True,
                                "reflection": False,
                                "title": "Gradle Plugin",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/system-options/87",
                                "internal": True,
                                "reflection": False,
                                "title": "System options",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/tab-completion-for-snaps/2261",
                                "internal": True,
                                "reflection": False,
                                "title": "Tab completion for snaps",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/process-for-aliases-auto-connections-and-tracks/455",
                                "internal": True,
                                "reflection": False,
                                "title": "Process for aliases, auto-connections and tracks",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-maven-plugin/4282",
                                "internal": True,
                                "reflection": False,
                                "title": "The maven plugin",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/enabling-swap-on-ubuntu-core/5440",
                                "internal": True,
                                "reflection": False,
                                "title": "Enabling swap on Ubuntu Core",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806",
                                "internal": True,
                                "reflection": True,
                                "title": "Experimental documentation site",
                                "clicks": 5,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/remote-part-tomcat-with-ssl/4264",
                                "internal": True,
                                "reflection": True,
                                "title": "Remote Part: tomcat-with-ssl",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806/20",
                                "internal": True,
                                "reflection": True,
                                "title": "Experimental documentation site",
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19558,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-10T19:36:11.807Z",
                        "cooked": "<p>Added a new <em>Commands and aliases</em> section.</p>",
                        "post_number": 2,
                        "post_type": 1,
                        "updated_at": "2018-02-10T19:36:11.807Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 12,
                        "incoming_link_count": 1,
                        "reads": 35,
                        "score": 32.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19631,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-11T23:04:48.257Z",
                        "cooked": "<p>… and Service management.</p>",
                        "post_number": 3,
                        "post_type": 1,
                        "updated_at": "2018-02-11T23:04:48.257Z",
                        "reply_count": 0,
                        "reply_to_post_number": 2,
                        "quote_count": 0,
                        "avg_time": 13,
                        "incoming_link_count": 4,
                        "reads": 30,
                        "score": 41.65,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33091,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-06T07:18:29.609Z",
                        "cooked": '<p>Could we pin this topic (the one with the navigation) to the top of the “doc” category?</p>\n<p>I always arrive at <a href="https://forum.snapcraft.io/c/doc">https://forum.snapcraft.io/c/doc</a> looking for it, can’t find it, and ultimately have to go to <a href="https://snapdocs.labix.org/" rel="nofollow noopener">https://snapdocs.labix.org/</a> and click “the forum topic” in the footer to find it.</p>',
                        "post_number": 4,
                        "post_type": 1,
                        "updated_at": "2018-09-06T08:04:16.850Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 28,
                        "incoming_link_count": 2,
                        "reads": 16,
                        "score": 79.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 2,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://snapdocs.labix.org/",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/c/doc",
                                "internal": True,
                                "reflection": False,
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33092,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-06T07:23:11.967Z",
                        "cooked": "<p>Would it be okay to add a <code>&lt;hr&gt;</code> (<code>---</code>in markdown) above the “Content” heading on this topic?</p>\n<p>It would more clearly separate the introduction from the navigation for the user, and would make it easier for</p>",
                        "post_number": 5,
                        "post_type": 1,
                        "updated_at": "2018-09-06T07:23:11.967Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 30,
                        "incoming_link_count": 1,
                        "reads": 16,
                        "score": 29.7,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33181,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-07T08:55:55.978Z",
                        "cooked": "",
                        "post_number": 6,
                        "post_type": 3,
                        "updated_at": "2018-09-07T08:55:55.978Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 24,
                        "incoming_link_count": 0,
                        "reads": 14,
                        "score": 4.0,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "action_code": "pinned.enabled",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33182,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-07T08:56:49.820Z",
                        "cooked": "<p>Good idea - I’ve been doing the same. Now pinned.</p>",
                        "post_number": 7,
                        "post_type": 1,
                        "updated_at": "2018-09-07T08:56:49.820Z",
                        "reply_count": 1,
                        "reply_to_post_number": 4,
                        "quote_count": 0,
                        "avg_time": 29,
                        "incoming_link_count": 1,
                        "reads": 14,
                        "score": 104.25,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33190,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-09-07T09:59:07.674Z",
                        "cooked": '<p>We can’t add that line because that content goes into the actual documentation header and welcome page. If we add a line here, a line gets added there. See page <a href="http://snapdocs.labix.org">snapdocs.labix.org</a> for a live (cached for 1h) snapshot of the content here.</p>',
                        "post_number": 8,
                        "post_type": 1,
                        "updated_at": "2018-09-07T09:59:07.674Z",
                        "reply_count": 2,
                        "reply_to_post_number": 5,
                        "quote_count": 0,
                        "avg_time": 38,
                        "incoming_link_count": 1,
                        "reads": 13,
                        "score": 19.5,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "http://snapdocs.labix.org",
                                "internal": False,
                                "reflection": False,
                                "clicks": 3,
                            }
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33196,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-07T12:00:55.756Z",
                        "cooked": "<p>Yep makes sense. We can tweak that after the new version lands.</p>",
                        "post_number": 9,
                        "post_type": 1,
                        "updated_at": "2018-09-07T12:00:55.756Z",
                        "reply_count": 0,
                        "reply_to_post_number": 8,
                        "quote_count": 0,
                        "avg_time": 60,
                        "incoming_link_count": 1,
                        "reads": 12,
                        "score": 10.4,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33357,
                        "name": "Daniel Llewellyn",
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "created_at": "2018-09-09T21:24:50.082Z",
                        "cooked": "<p>Can you pin the <em>first</em> post in this thread instead of the 8th comment which is what you’ve got pinned right now? Oh well fudge, the forum does that automatically according to where it detected you’ve read down to. That’s helpful if you weren’t reading a page for documentation.</p>",
                        "post_number": 10,
                        "post_type": 1,
                        "updated_at": "2018-09-09T21:26:30.988Z",
                        "reply_count": 0,
                        "reply_to_post_number": 7,
                        "quote_count": 0,
                        "avg_time": 74,
                        "incoming_link_count": 1,
                        "reads": 10,
                        "score": 10.7,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Daniel Llewellyn",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "degville",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 286,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33358,
                        "name": "Daniel Llewellyn",
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "created_at": "2018-09-09T21:28:34.469Z",
                        "cooked": '<aside class="quote no-group" data-post="8" data-topic="3781">\n<div class="title">\n<div class="quote-controls"></div>\n<img alt width="20" height="20" src="https://forum.snapcraft.io/user_avatar/forum.snapcraft.io/niemeyer/40/13_1.png" class="avatar"> niemeyer:</div>\n<blockquote>\n<p>See page <a href="http://snapdocs.labix.org" rel="nofollow noopener">snapdocs.labix.org </a> for a live (cached for 1h) snapshot of the content here.</p>\n</blockquote>\n</aside>\n<p>Just when is this documentation experiment, that has been thoroughly told to me isn’t an experiment anymore and is the only way we’re going to do things, going to replace the <a href="http://docs.snapcraft.io" rel="nofollow noopener">docs.snapcraft.io</a> documentation???! Trying to remember the domain <a href="http://snapdocs.labix.org" rel="nofollow noopener">snapdocs.labix.org</a> is a pain and rather impossible. Also it looks unprofessional when we point users there.</p>',
                        "post_number": 11,
                        "post_type": 1,
                        "updated_at": "2018-09-09T21:29:41.902Z",
                        "reply_count": 1,
                        "reply_to_post_number": 8,
                        "quote_count": 1,
                        "avg_time": 72,
                        "incoming_link_count": 1,
                        "reads": 10,
                        "score": 15.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Daniel Llewellyn",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "http://snapdocs.labix.org",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                            {
                                "url": "http://docs.snapcraft.io",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 286,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33687,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-13T12:57:53.508Z",
                        "cooked": "<p>Thanks for the prod, and you’re absolutely right. We’re currently working on moving these docs over ASAP - even to the point of having daily meetings on the process. We can’t quite commit to a date yet, but we’re hoping the docs transfer will be soon.</p>",
                        "post_number": 12,
                        "post_type": 1,
                        "updated_at": "2018-09-13T12:57:53.508Z",
                        "reply_count": 0,
                        "reply_to_post_number": 11,
                        "quote_count": 0,
                        "avg_time": 39,
                        "incoming_link_count": 1,
                        "reads": 8,
                        "score": 68.55,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "daniel",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        },
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33762,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-14T10:59:07.369Z",
                        "cooked": '<p><a class="mention" href="/u/degville">@degville</a> Could we please update the redirected links in the navigation to their new targets?</p>\n<ul>\n<li>\n<code>/t/configuration-options/87</code> -&gt; <code>/t/system-options/87</code>\n</li>\n<li>\n<code>/t/enabling-swap-on-core/5440</code> -&gt; <code>/t/enabling-swap-on-ubuntu-core/5440</code>\n</li>\n<li>\n<code>/t/permission-requests/455</code> -&gt; <code>/t/process-for-aliases-auto-connections-and-tracks/455</code>\n</li>\n<li>\n<code>/t/tab-completion/2261</code> -&gt; <code>/t/tab-completion-for-snaps/2261</code>\n</li>\n<li>\n<code>/t/mavin-plugin/4282</code> -&gt; <code>/t/the-maven-plugin/4282</code>\n</li>\n</ul>\n<p>Of if you could give me access to edit it myself, I’ll go ahead and do it.</p>',
                        "post_number": 13,
                        "post_type": 1,
                        "updated_at": "2018-09-14T10:59:07.369Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 80,
                        "incoming_link_count": 1,
                        "reads": 6,
                        "score": 15.2,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33771,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-14T12:27:07.940Z",
                        "cooked": '<p><a class="mention" href="/u/nottrobin">@nottrobin</a> I’ve just updated those links.</p>',
                        "post_number": 14,
                        "post_type": 1,
                        "updated_at": "2018-09-14T12:27:07.940Z",
                        "reply_count": 0,
                        "reply_to_post_number": 13,
                        "quote_count": 0,
                        "avg_time": 28,
                        "incoming_link_count": 1,
                        "reads": 6,
                        "score": 22.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                ],
                "stream": [
                    18694,
                    19558,
                    19631,
                    33091,
                    33092,
                    33181,
                    33182,
                    33190,
                    33196,
                    33357,
                    33358,
                    33687,
                    33762,
                    33771,
                ],
            },
            "timeline_lookup": [
                [1, 231],
                [2, 220],
                [3, 219],
                [4, 13],
                [6, 11],
                [10, 9],
                [12, 5],
                [13, 4],
            ],
            "suggested_topics": [
                {
                    "id": 5502,
                    "title": "Create Security documentation",
                    "fancy_title": "Create Security documentation",
                    "slug": "create-security-documentation",
                    "posts_count": 5,
                    "reply_count": 1,
                    "highest_post_number": 5,
                    "image_url": None,
                    "created_at": "2018-05-18T09:08:53.203Z",
                    "last_posted_at": "2018-05-18T10:12:03.215Z",
                    "bumped": True,
                    "bumped_at": "2018-05-18T10:12:03.215Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 207,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 1936,
                                "username": "ssspacez",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ssspacez/{size}/1400_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 9,
                                "username": "ogra",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ogra/{size}/22_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6233,
                    "title": "Snap Confinement",
                    "fancy_title": "Snap Confinement",
                    "slug": "snap-confinement",
                    "posts_count": 5,
                    "reply_count": 2,
                    "highest_post_number": 5,
                    "image_url": None,
                    "created_at": "2018-07-04T09:17:44.850Z",
                    "last_posted_at": "2018-09-09T15:49:38.714Z",
                    "bumped": True,
                    "bumped_at": "2018-09-09T15:56:15.594Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 2,
                    "views": 148,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 14,
                                "username": "popey",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/popey/{size}/29_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 286,
                                "username": "daniel",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 1417,
                                "username": "Lin-Buo-Ren",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 2261,
                    "title": "Tab completion for snaps",
                    "fancy_title": "Tab completion for snaps",
                    "slug": "tab-completion-for-snaps",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2017-09-26T12:41:35.913Z",
                    "last_posted_at": "2017-09-26T12:41:35.993Z",
                    "bumped": True,
                    "bumped_at": "2018-02-07T02:25:50.833Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 3,
                    "views": 792,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 1044,
                                "username": "wiki",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 4972,
                    "title": "Architectures",
                    "fancy_title": "Architectures",
                    "slug": "architectures",
                    "posts_count": 6,
                    "reply_count": 2,
                    "highest_post_number": 6,
                    "image_url": None,
                    "created_at": "2018-04-12T21:32:37.740Z",
                    "last_posted_at": "2018-09-04T08:56:21.000Z",
                    "bumped": True,
                    "bumped_at": "2018-09-04T08:56:21.000Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 6,
                    "views": 397,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 17,
                                "username": "kyrofa",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/kyrofa/{size}/685_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 2126,
                                "username": "eberkund",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/e/8dc957/{size}.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 9,
                                "username": "ogra",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ogra/{size}/22_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6273,
                    "title": "Adding OpenGL/GPU support to a snap",
                    "fancy_title": "Adding OpenGL/GPU support to a snap",
                    "slug": "adding-opengl-gpu-support-to-a-snap",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-07-06T11:49:22.338Z",
                    "last_posted_at": "2018-07-06T11:49:22.515Z",
                    "bumped": True,
                    "bumped_at": "2018-07-06T12:16:58.542Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 118,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 20,
                                "username": "Wimpress",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/wimpress/{size}/1934_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 3781,
            "title": "Documentation outline",
            "fancy_title": "Documentation outline",
            "posts_count": 14,
            "created_at": "2018-01-31T01:35:55.823Z",
            "views": 1620,
            "reply_count": 8,
            "like_count": 12,
            "last_posted_at": "2018-09-14T12:27:07.940Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "documentation-outline",
            "category_id": 15,
            "word_count": 771,
            "deleted_at": None,
            "user_id": 2772,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": "2018-09-07T08:55:55.690Z",
            "pinned_until": "2019-09-06T00:00:00.000Z",
            "draft": None,
            "draft_key": "topic_3781",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": True,
            "details": {
                "created_by": {
                    "id": 2772,
                    "username": "degville",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                },
                "last_poster": {
                    "id": 2772,
                    "username": "degville",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                },
                "participants": [
                    {
                        "id": 2772,
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "post_count": 5,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 898,
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "post_count": 4,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1,
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "post_count": 3,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 286,
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/getting-started/3876",
                        "title": "Getting started",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 79,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snap-format/698",
                        "title": "The snap format",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 22,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                        "title": "Commands and aliases",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 18,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snap-directory/2817",
                        "title": "The /snap directory",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 17,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/documentation-guidelines/3798",
                        "title": "Documentation guidelines",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 17,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                        "title": "Configuration in snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 15,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/service-management/3965",
                        "title": "Service management",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 14,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "/t/5464",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 13,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/channels/551",
                        "title": "Channels",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 13,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-gadget-snap/696",
                        "title": "The gadget snap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 10,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-kernel-snap/697",
                        "title": "The kernel snap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snapd-roadmap/1973",
                        "title": "The snapd roadmap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/clean-build-using-lxc/4157",
                        "title": "Clean build - using LXC",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 6,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/supported-snap-hooks/3795",
                        "title": "Supported snap hooks",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 6,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806",
                        "title": "Experimental documentation site",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 5,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-dbus-interface/2038",
                        "title": "The dbus interface",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 5,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/build-on-docker/4158",
                        "title": "Build on Docker",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-content-interface/1074",
                        "title": "The content interface",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-desktop-interfaces/2042",
                        "title": "The desktop interfaces",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "http://snapdocs.labix.org",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 3,
                        "user_id": 1,
                        "domain": "snapdocs.labix.org",
                        "root_domain": "labix.org",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/remote-reusable-parts/4233",
                        "title": "Remote (reusable) parts",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 2,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/remote-part-tomcat-with-ssl/4264",
                        "title": "Remote Part: tomcat-with-ssl",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1814,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/gradle-plugin/5390",
                        "title": "Gradle Plugin",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/snapcraft-plugins/4284",
                        "title": "Snapcraft Plugins",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/system-options/87",
                        "title": "System options",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/tab-completion-for-snaps/2261",
                        "title": "Tab completion for snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/process-for-aliases-auto-connections-and-tracks/455",
                        "title": "Process for aliases, auto-connections and tracks",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806/20",
                        "title": "Experimental documentation site",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 95,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-maven-plugin/4282",
                        "title": "The maven plugin",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/enabling-swap-on-ubuntu-core/5440",
                        "title": "Enabling swap on Ubuntu Core",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/c/doc",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 898,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "http://docs.snapcraft.io",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 286,
                        "domain": "docs.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://snapdocs.labix.org/",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 898,
                        "domain": "snapdocs.labix.org",
                        "root_domain": "labix.org",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 14,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 40,
            "participant_count": 4,
        },
        status_code=200,
        headers={
            "Date": "Wed, 19 Sep 2018 08:50:34 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "075d3257-8450-4293-b4ee-33649c36a95e",
            "X-Runtime": "0.363330",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/3781.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 18694,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-01-31T01:35:55.952Z",
                        "cooked": '<p>This is the experimental snap, snapd, and snapcraft documentation that is being worked on to eventually become the main source of information about how to use and publish snaps, and how to develop the tools around them.</p>\n<p>Most of this documentation can be collaboratively discussed and changed in the respective topic in the forum. See the <a href="/t/documentation-guidelines/3798">documentation guidelines</a> if you’d like to contribute.</p>\n<p>Choose the topic you’d like to read about.</p>\n<h1>Content</h1>\n<h3>Using</h3>\n<ul>\n<li><a href="/t/getting-started/3876">Getting started</a></li>\n<li><a href="/t/channels/551">Channels</a></li>\n<li><a href="/t/commands-and-aliases/3950">Commands and aliases</a></li>\n<li><a href="/t/service-management/3965">Service management</a></li>\n<li><a href="/t/configuration-in-snaps/510">Configuration in snaps</a></li>\n<li><a href="/t/system-options/87">System options</a></li>\n<li><a href="/t/the-snap-directory/2817">The /snap directory</a></li>\n<li><a href="/t/enabling-swap-on-ubuntu-core/5440">Enabling swap on Ubuntu Core</a></li>\n<li><a href="/t/5464">Ubuntu Core boot mode explained</a></li>\n</ul>\n\n<h3>Publishing</h3>\n<ul>\n<li><a href="/t/the-snap-format/698">The snap format</a></li>\n<li><a href="/t/the-gadget-snap/696">The gadget snap</a></li>\n<li><a href="/t/the-kernel-snap/697">The kernel snap</a></li>\n<li><a href="/t/the-content-interface/1074">The content interface</a></li>\n<li><a href="/t/the-dbus-interface/2038">The dbus interface</a></li>\n<li><a href="/t/the-desktop-interfaces/2042">The desktop interfaces</a></li>\n<li><a href="/t/supported-snap-hooks/3795">Supported hooks</a></li>\n<li><a href="/t/process-for-aliases-auto-connections-and-tracks/455">Permission requests</a></li>\n<li><a href="/t/tab-completion-for-snaps/2261">Tab completion</a></li>\n<li><a href="/t/clean-build-using-lxc/4157">Building with LXD</a></li>\n<li><a href="/t/build-on-docker/4158">Building with Docker</a></li>\n<li><a href="/t/remote-reusable-parts/4233">Building reusable parts</a></li>\n<li>\n<a href="/t/snapcraft-plugins/4284">Snapcraft plugins</a>\n<ul>\n<li><a href="/t/the-maven-plugin/4282">Maven</a></li>\n<li><a href="/t/gradle-plugin/5390">Gradle</a></li>\n</ul>\n</li>\n</ul>\n\n<h3>Developing</h3>\n<ul>\n<li><a href="/t/the-snapd-roadmap/1973">Roadmap</a></li>\n<li><a href="/t/documentation-guidelines/3798">Documentation guidelines</a></li>\n</ul>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2018-09-14T12:26:06.298Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 40,
                        "incoming_link_count": 140,
                        "reads": 65,
                        "score": 744.0,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 32,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/getting-started/3876",
                                "internal": True,
                                "reflection": False,
                                "title": "Getting started",
                                "clicks": 79,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snap-format/698",
                                "internal": True,
                                "reflection": False,
                                "title": "The snap format",
                                "clicks": 22,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                                "internal": True,
                                "reflection": False,
                                "title": "Commands and aliases",
                                "clicks": 18,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/documentation-guidelines/3798",
                                "internal": True,
                                "reflection": False,
                                "title": "Documentation guidelines",
                                "clicks": 17,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snap-directory/2817",
                                "internal": True,
                                "reflection": False,
                                "title": "The /snap directory",
                                "clicks": 17,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                                "internal": True,
                                "reflection": False,
                                "title": "Configuration in snaps",
                                "clicks": 15,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/service-management/3965",
                                "internal": True,
                                "reflection": False,
                                "title": "Service management",
                                "clicks": 14,
                            },
                            {
                                "url": "/t/5464",
                                "internal": True,
                                "reflection": False,
                                "clicks": 13,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/channels/551",
                                "internal": True,
                                "reflection": False,
                                "title": "Channels",
                                "clicks": 13,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-gadget-snap/696",
                                "internal": True,
                                "reflection": False,
                                "title": "The gadget snap",
                                "clicks": 10,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-kernel-snap/697",
                                "internal": True,
                                "reflection": False,
                                "title": "The kernel snap",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-snapd-roadmap/1973",
                                "internal": True,
                                "reflection": False,
                                "title": "The snapd roadmap",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/clean-build-using-lxc/4157",
                                "internal": True,
                                "reflection": False,
                                "title": "Clean build - using LXC",
                                "clicks": 6,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/supported-snap-hooks/3795",
                                "internal": True,
                                "reflection": False,
                                "title": "Supported snap hooks",
                                "clicks": 6,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-dbus-interface/2038",
                                "internal": True,
                                "reflection": False,
                                "title": "The dbus interface",
                                "clicks": 5,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-desktop-interfaces/2042",
                                "internal": True,
                                "reflection": False,
                                "title": "The desktop interfaces",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-content-interface/1074",
                                "internal": True,
                                "reflection": False,
                                "title": "The content interface",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/build-on-docker/4158",
                                "internal": True,
                                "reflection": False,
                                "title": "Build on Docker",
                                "clicks": 4,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/remote-reusable-parts/4233",
                                "internal": True,
                                "reflection": False,
                                "title": "Remote (reusable) parts",
                                "clicks": 2,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/snapcraft-plugins/4284",
                                "internal": True,
                                "reflection": False,
                                "title": "Snapcraft Plugins",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/gradle-plugin/5390",
                                "internal": True,
                                "reflection": False,
                                "title": "Gradle Plugin",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/system-options/87",
                                "internal": True,
                                "reflection": False,
                                "title": "System options",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/tab-completion-for-snaps/2261",
                                "internal": True,
                                "reflection": False,
                                "title": "Tab completion for snaps",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/process-for-aliases-auto-connections-and-tracks/455",
                                "internal": True,
                                "reflection": False,
                                "title": "Process for aliases, auto-connections and tracks",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/the-maven-plugin/4282",
                                "internal": True,
                                "reflection": False,
                                "title": "The maven plugin",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/enabling-swap-on-ubuntu-core/5440",
                                "internal": True,
                                "reflection": False,
                                "title": "Enabling swap on Ubuntu Core",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806",
                                "internal": True,
                                "reflection": True,
                                "title": "Experimental documentation site",
                                "clicks": 5,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/remote-part-tomcat-with-ssl/4264",
                                "internal": True,
                                "reflection": True,
                                "title": "Remote Part: tomcat-with-ssl",
                                "clicks": 1,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806/20",
                                "internal": True,
                                "reflection": True,
                                "title": "Experimental documentation site",
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19558,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-10T19:36:11.807Z",
                        "cooked": "<p>Added a new <em>Commands and aliases</em> section.</p>",
                        "post_number": 2,
                        "post_type": 1,
                        "updated_at": "2018-02-10T19:36:11.807Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 12,
                        "incoming_link_count": 1,
                        "reads": 35,
                        "score": 32.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19631,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-11T23:04:48.257Z",
                        "cooked": "<p>… and Service management.</p>",
                        "post_number": 3,
                        "post_type": 1,
                        "updated_at": "2018-02-11T23:04:48.257Z",
                        "reply_count": 0,
                        "reply_to_post_number": 2,
                        "quote_count": 0,
                        "avg_time": 13,
                        "incoming_link_count": 4,
                        "reads": 30,
                        "score": 41.65,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33091,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-06T07:18:29.609Z",
                        "cooked": '<p>Could we pin this topic (the one with the navigation) to the top of the “doc” category?</p>\n<p>I always arrive at <a href="https://forum.snapcraft.io/c/doc">https://forum.snapcraft.io/c/doc</a> looking for it, can’t find it, and ultimately have to go to <a href="https://snapdocs.labix.org/" rel="nofollow noopener">https://snapdocs.labix.org/</a> and click “the forum topic” in the footer to find it.</p>',
                        "post_number": 4,
                        "post_type": 1,
                        "updated_at": "2018-09-06T08:04:16.850Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 28,
                        "incoming_link_count": 2,
                        "reads": 16,
                        "score": 79.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 2,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://snapdocs.labix.org/",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/c/doc",
                                "internal": True,
                                "reflection": False,
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33092,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-06T07:23:11.967Z",
                        "cooked": "<p>Would it be okay to add a <code>&lt;hr&gt;</code> (<code>---</code>in markdown) above the “Content” heading on this topic?</p>\n<p>It would more clearly separate the introduction from the navigation for the user, and would make it easier for</p>",
                        "post_number": 5,
                        "post_type": 1,
                        "updated_at": "2018-09-06T07:23:11.967Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 30,
                        "incoming_link_count": 1,
                        "reads": 16,
                        "score": 29.7,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33181,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-07T08:55:55.978Z",
                        "cooked": "",
                        "post_number": 6,
                        "post_type": 3,
                        "updated_at": "2018-09-07T08:55:55.978Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 24,
                        "incoming_link_count": 0,
                        "reads": 14,
                        "score": 4.0,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "action_code": "pinned.enabled",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33182,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-07T08:56:49.820Z",
                        "cooked": "<p>Good idea - I’ve been doing the same. Now pinned.</p>",
                        "post_number": 7,
                        "post_type": 1,
                        "updated_at": "2018-09-07T08:56:49.820Z",
                        "reply_count": 1,
                        "reply_to_post_number": 4,
                        "quote_count": 0,
                        "avg_time": 29,
                        "incoming_link_count": 1,
                        "reads": 14,
                        "score": 104.25,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33190,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-09-07T09:59:07.674Z",
                        "cooked": '<p>We can’t add that line because that content goes into the actual documentation header and welcome page. If we add a line here, a line gets added there. See page <a href="http://snapdocs.labix.org">snapdocs.labix.org</a> for a live (cached for 1h) snapshot of the content here.</p>',
                        "post_number": 8,
                        "post_type": 1,
                        "updated_at": "2018-09-07T09:59:07.674Z",
                        "reply_count": 2,
                        "reply_to_post_number": 5,
                        "quote_count": 0,
                        "avg_time": 38,
                        "incoming_link_count": 1,
                        "reads": 13,
                        "score": 19.5,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "http://snapdocs.labix.org",
                                "internal": False,
                                "reflection": False,
                                "clicks": 3,
                            }
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33196,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-07T12:00:55.756Z",
                        "cooked": "<p>Yep makes sense. We can tweak that after the new version lands.</p>",
                        "post_number": 9,
                        "post_type": 1,
                        "updated_at": "2018-09-07T12:00:55.756Z",
                        "reply_count": 0,
                        "reply_to_post_number": 8,
                        "quote_count": 0,
                        "avg_time": 60,
                        "incoming_link_count": 1,
                        "reads": 12,
                        "score": 10.4,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33357,
                        "name": "Daniel Llewellyn",
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "created_at": "2018-09-09T21:24:50.082Z",
                        "cooked": "<p>Can you pin the <em>first</em> post in this thread instead of the 8th comment which is what you’ve got pinned right now? Oh well fudge, the forum does that automatically according to where it detected you’ve read down to. That’s helpful if you weren’t reading a page for documentation.</p>",
                        "post_number": 10,
                        "post_type": 1,
                        "updated_at": "2018-09-09T21:26:30.988Z",
                        "reply_count": 0,
                        "reply_to_post_number": 7,
                        "quote_count": 0,
                        "avg_time": 74,
                        "incoming_link_count": 1,
                        "reads": 10,
                        "score": 10.7,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Daniel Llewellyn",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "degville",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 286,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33358,
                        "name": "Daniel Llewellyn",
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "created_at": "2018-09-09T21:28:34.469Z",
                        "cooked": '<aside class="quote no-group" data-post="8" data-topic="3781">\n<div class="title">\n<div class="quote-controls"></div>\n<img alt width="20" height="20" src="https://forum.snapcraft.io/user_avatar/forum.snapcraft.io/niemeyer/40/13_1.png" class="avatar"> niemeyer:</div>\n<blockquote>\n<p>See page <a href="http://snapdocs.labix.org" rel="nofollow noopener">snapdocs.labix.org </a> for a live (cached for 1h) snapshot of the content here.</p>\n</blockquote>\n</aside>\n<p>Just when is this documentation experiment, that has been thoroughly told to me isn’t an experiment anymore and is the only way we’re going to do things, going to replace the <a href="http://docs.snapcraft.io" rel="nofollow noopener">docs.snapcraft.io</a> documentation???! Trying to remember the domain <a href="http://snapdocs.labix.org" rel="nofollow noopener">snapdocs.labix.org</a> is a pain and rather impossible. Also it looks unprofessional when we point users there.</p>',
                        "post_number": 11,
                        "post_type": 1,
                        "updated_at": "2018-09-09T21:29:41.902Z",
                        "reply_count": 1,
                        "reply_to_post_number": 8,
                        "quote_count": 1,
                        "avg_time": 72,
                        "incoming_link_count": 1,
                        "reads": 10,
                        "score": 15.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Daniel Llewellyn",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "http://snapdocs.labix.org",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                            {
                                "url": "http://docs.snapcraft.io",
                                "internal": False,
                                "reflection": False,
                                "clicks": 0,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 286,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33687,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-13T12:57:53.508Z",
                        "cooked": "<p>Thanks for the prod, and you’re absolutely right. We’re currently working on moving these docs over ASAP - even to the point of having daily meetings on the process. We can’t quite commit to a date yet, but we’re hoping the docs transfer will be soon.</p>",
                        "post_number": 12,
                        "post_type": 1,
                        "updated_at": "2018-09-13T12:57:53.508Z",
                        "reply_count": 0,
                        "reply_to_post_number": 11,
                        "quote_count": 0,
                        "avg_time": 39,
                        "incoming_link_count": 1,
                        "reads": 8,
                        "score": 68.55,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "daniel",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        },
                        "actions_summary": [{"id": 2, "count": 2}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33762,
                        "name": "Robin",
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "created_at": "2018-09-14T10:59:07.369Z",
                        "cooked": '<p><a class="mention" href="/u/degville">@degville</a> Could we please update the redirected links in the navigation to their new targets?</p>\n<ul>\n<li>\n<code>/t/configuration-options/87</code> -&gt; <code>/t/system-options/87</code>\n</li>\n<li>\n<code>/t/enabling-swap-on-core/5440</code> -&gt; <code>/t/enabling-swap-on-ubuntu-core/5440</code>\n</li>\n<li>\n<code>/t/permission-requests/455</code> -&gt; <code>/t/process-for-aliases-auto-connections-and-tracks/455</code>\n</li>\n<li>\n<code>/t/tab-completion/2261</code> -&gt; <code>/t/tab-completion-for-snaps/2261</code>\n</li>\n<li>\n<code>/t/mavin-plugin/4282</code> -&gt; <code>/t/the-maven-plugin/4282</code>\n</li>\n</ul>\n<p>Of if you could give me access to edit it myself, I’ll go ahead and do it.</p>',
                        "post_number": 13,
                        "post_type": 1,
                        "updated_at": "2018-09-14T10:59:07.369Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 80,
                        "incoming_link_count": 1,
                        "reads": 6,
                        "score": 15.2,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Robin",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 898,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 33771,
                        "name": "Graham Morrison",
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "created_at": "2018-09-14T12:27:07.940Z",
                        "cooked": '<p><a class="mention" href="/u/nottrobin">@nottrobin</a> I’ve just updated those links.</p>',
                        "post_number": 14,
                        "post_type": 1,
                        "updated_at": "2018-09-14T12:27:07.940Z",
                        "reply_count": 0,
                        "reply_to_post_number": 13,
                        "quote_count": 0,
                        "avg_time": 28,
                        "incoming_link_count": 1,
                        "reads": 6,
                        "score": 22.6,
                        "yours": False,
                        "topic_id": 3781,
                        "topic_slug": "documentation-outline",
                        "display_username": "Graham Morrison",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "nottrobin",
                            "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        },
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": True,
                        "admin": False,
                        "staff": True,
                        "user_id": 2772,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                ],
                "stream": [
                    18694,
                    19558,
                    19631,
                    33091,
                    33092,
                    33181,
                    33182,
                    33190,
                    33196,
                    33357,
                    33358,
                    33687,
                    33762,
                    33771,
                ],
            },
            "timeline_lookup": [
                [1, 231],
                [2, 220],
                [3, 219],
                [4, 13],
                [6, 11],
                [10, 9],
                [12, 5],
                [13, 4],
            ],
            "suggested_topics": [
                {
                    "id": 5502,
                    "title": "Create Security documentation",
                    "fancy_title": "Create Security documentation",
                    "slug": "create-security-documentation",
                    "posts_count": 5,
                    "reply_count": 1,
                    "highest_post_number": 5,
                    "image_url": None,
                    "created_at": "2018-05-18T09:08:53.203Z",
                    "last_posted_at": "2018-05-18T10:12:03.215Z",
                    "bumped": True,
                    "bumped_at": "2018-05-18T10:12:03.215Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 207,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 1936,
                                "username": "ssspacez",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ssspacez/{size}/1400_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 9,
                                "username": "ogra",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ogra/{size}/22_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6233,
                    "title": "Snap Confinement",
                    "fancy_title": "Snap Confinement",
                    "slug": "snap-confinement",
                    "posts_count": 5,
                    "reply_count": 2,
                    "highest_post_number": 5,
                    "image_url": None,
                    "created_at": "2018-07-04T09:17:44.850Z",
                    "last_posted_at": "2018-09-09T15:49:38.714Z",
                    "bumped": True,
                    "bumped_at": "2018-09-09T15:56:15.594Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 2,
                    "views": 148,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 14,
                                "username": "popey",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/popey/{size}/29_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 286,
                                "username": "daniel",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 1417,
                                "username": "Lin-Buo-Ren",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 2261,
                    "title": "Tab completion for snaps",
                    "fancy_title": "Tab completion for snaps",
                    "slug": "tab-completion-for-snaps",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2017-09-26T12:41:35.913Z",
                    "last_posted_at": "2017-09-26T12:41:35.993Z",
                    "bumped": True,
                    "bumped_at": "2018-02-07T02:25:50.833Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 3,
                    "views": 792,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 1044,
                                "username": "wiki",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 4972,
                    "title": "Architectures",
                    "fancy_title": "Architectures",
                    "slug": "architectures",
                    "posts_count": 6,
                    "reply_count": 2,
                    "highest_post_number": 6,
                    "image_url": None,
                    "created_at": "2018-04-12T21:32:37.740Z",
                    "last_posted_at": "2018-09-04T08:56:21.000Z",
                    "bumped": True,
                    "bumped_at": "2018-09-04T08:56:21.000Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 6,
                    "views": 397,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 17,
                                "username": "kyrofa",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/kyrofa/{size}/685_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 2126,
                                "username": "eberkund",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/e/8dc957/{size}.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 9,
                                "username": "ogra",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/ogra/{size}/22_1.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6273,
                    "title": "Adding OpenGL/GPU support to a snap",
                    "fancy_title": "Adding OpenGL/GPU support to a snap",
                    "slug": "adding-opengl-gpu-support-to-a-snap",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-07-06T11:49:22.338Z",
                    "last_posted_at": "2018-07-06T11:49:22.515Z",
                    "bumped": True,
                    "bumped_at": "2018-07-06T12:16:58.542Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 118,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 20,
                                "username": "Wimpress",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/wimpress/{size}/1934_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 3781,
            "title": "Documentation outline",
            "fancy_title": "Documentation outline",
            "posts_count": 14,
            "created_at": "2018-01-31T01:35:55.823Z",
            "views": 1620,
            "reply_count": 8,
            "like_count": 12,
            "last_posted_at": "2018-09-14T12:27:07.940Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "documentation-outline",
            "category_id": 15,
            "word_count": 771,
            "deleted_at": None,
            "user_id": 2772,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": "2018-09-07T08:55:55.690Z",
            "pinned_until": "2019-09-06T00:00:00.000Z",
            "draft": None,
            "draft_key": "topic_3781",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": True,
            "details": {
                "created_by": {
                    "id": 2772,
                    "username": "degville",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                },
                "last_poster": {
                    "id": 2772,
                    "username": "degville",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                },
                "participants": [
                    {
                        "id": 2772,
                        "username": "degville",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                        "post_count": 5,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 898,
                        "username": "nottrobin",
                        "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                        "post_count": 4,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1,
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "post_count": 3,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 286,
                        "username": "daniel",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/getting-started/3876",
                        "title": "Getting started",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 79,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snap-format/698",
                        "title": "The snap format",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 22,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                        "title": "Commands and aliases",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 18,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snap-directory/2817",
                        "title": "The /snap directory",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 17,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/documentation-guidelines/3798",
                        "title": "Documentation guidelines",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 17,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                        "title": "Configuration in snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 15,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/service-management/3965",
                        "title": "Service management",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 14,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "/t/5464",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 13,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/channels/551",
                        "title": "Channels",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 13,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-gadget-snap/696",
                        "title": "The gadget snap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 10,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-kernel-snap/697",
                        "title": "The kernel snap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-snapd-roadmap/1973",
                        "title": "The snapd roadmap",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/clean-build-using-lxc/4157",
                        "title": "Clean build - using LXC",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 6,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/supported-snap-hooks/3795",
                        "title": "Supported snap hooks",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 6,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806",
                        "title": "Experimental documentation site",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 5,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-dbus-interface/2038",
                        "title": "The dbus interface",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 5,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/build-on-docker/4158",
                        "title": "Build on Docker",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-content-interface/1074",
                        "title": "The content interface",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-desktop-interfaces/2042",
                        "title": "The desktop interfaces",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "http://snapdocs.labix.org",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 3,
                        "user_id": 1,
                        "domain": "snapdocs.labix.org",
                        "root_domain": "labix.org",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/remote-reusable-parts/4233",
                        "title": "Remote (reusable) parts",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 2,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/remote-part-tomcat-with-ssl/4264",
                        "title": "Remote Part: tomcat-with-ssl",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1814,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/gradle-plugin/5390",
                        "title": "Gradle Plugin",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/snapcraft-plugins/4284",
                        "title": "Snapcraft Plugins",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/system-options/87",
                        "title": "System options",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 1,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/tab-completion-for-snaps/2261",
                        "title": "Tab completion for snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/process-for-aliases-auto-connections-and-tracks/455",
                        "title": "Process for aliases, auto-connections and tracks",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/experimental-documentation-site/3806/20",
                        "title": "Experimental documentation site",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 95,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/the-maven-plugin/4282",
                        "title": "The maven plugin",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/enabling-swap-on-ubuntu-core/5440",
                        "title": "Enabling swap on Ubuntu Core",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/c/doc",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 898,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "http://docs.snapcraft.io",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 286,
                        "domain": "docs.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://snapdocs.labix.org/",
                        "title": None,
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 898,
                        "domain": "snapdocs.labix.org",
                        "root_domain": "labix.org",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 14,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 40,
            "participant_count": 4,
        },
        status_code=200,
        headers={
            "Date": "Wed, 19 Sep 2018 08:50:34 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "075d3257-8450-4293-b4ee-33649c36a95e",
            "X-Runtime": "0.363330",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/getting-started/3876.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 19156,
                        "name": "Wiki Content",
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "created_at": "2018-02-06T01:44:42.553Z",
                        "cooked": '<aside class="quote no-group">\n<blockquote>\n<p><img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"> <strong>NOTE TO EDITORS</strong> <img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"></p>\n<p>This document is introductory material, and as such it is organized with a story line in mind. Each section builds upon information described in preceding sections. That also means the content is focused on foundational concepts, so it’s not a complete reference and not supposed to provide in-depth information about these aspects.</p>\n</blockquote>\n</aside>\n<p>The following sections provide a basic overview of using snaps, from their installation to their management and manipulation.</p>\n<h2>Installing  snapd</h2>\n<p>The <em>snapd</em> daemon manages the snap environment on the local system. Its installation will include the <em>snap</em> tool for interacting with snaps. You can check both are installed by attempting to run <code>snap version</code> on the command line:</p>\n<pre><code class="lang-bash">$ snap version\nsnap    2.35\nsnapd   2.35\nseries  16\nneon    16.04\nkernel  4.4.0-128-generic\n</code></pre>\n<p>If all is well, version numbers for the main system components will be output, as shown above.</p>\n<p>If the <em>snap</em> command is not found, or if the command takes a while to respond before reporting that <em>snapd is unavailable</em>, make sure <a href="/t/can-i-use-snaps/6735">snapd is properly installed</a> before continuing.</p>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ The <code>"$"</code> above represents the command line prompt. Sample commands come after this prompt with any relevant output shown below.</p>\n</blockquote>\n</aside>\n<h2>Searching for snaps</h2>\n<p>With snapd installed, snaps can be discovered, searched for, and installed  from the <a href="https://snapcraft.io/store" rel="nofollow noopener">Snap Store</a> and directly from the command line. For example, the following command returns a list of media players:</p>\n<pre><code class="lang-bash">$ snap find "media player"\nName  Version  Developer  Notes  Summary\n(...)\nvlc        3.0.4     videolan✓    -      The ultimate media player                                                                 \nmpv        0.26.0    casept       -      a free, open source, and cross-platform media player.  \n(...)\n</code></pre>\n<p>The <code>✓</code> alongside <em>videolan</em> in the above output indicates that the snap publisher has been verified.</p>\n<h2>Learning about a snap</h2>\n<p>The <em>snap info</em> command makes it easy to find more details about a specific snap. These details include what a snap does, who publishes it, the command(s) it provides and which channel versions are available for installation:</p>\n<pre><code class="lang-bash">$ snap info vlc\nname:      vlc\nsummary:   The ultimate media player\npublisher: VideoLAN✓\ncontact:   https://www.videolan.org/support/\ndescription: |\n  VLC is the VideoLAN project\'s media player.\n  (...)\nsnap-id: RT9mcUhVsRYrDLG8qnvGiy26NKvv6Qkd\ncommands:\n  - vlc\nchannels:\n  stable:    3.0.0                   (158) 197MB -\n  candidate: 3.0.0                   (158) 197MB -\n  beta:      3.0.0-5-g407d4ba        (160) 197MB -\n  edge:      4.0.0-dev-1218-g201542f (159) 197MB \n</code></pre>\n<h2>Installing a snap</h2>\n<p>Installing a snap is straightforward:</p>\n<pre><code class="lang-bash">$ sudo snap install vlc\n</code></pre>\n<p><a href="/t/channels/551">Channels</a> are an important snap concept. They define which release of a snap is installed and tracked for updates. The <em>stable</em> channel is used by default, but opting to install from a different channel is easily accomplished:</p>\n<pre><code class="lang-bash">$ sudo snap install --channel=edge vlc\n</code></pre>\n<p>After installation, the channel being tracked can be changed with:</p>\n<pre><code class="lang-bash">$ sudo snap switch --channel=stable vlc\n</code></pre>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ The <em>sudo</em> command ensures the command following it is executed as the <em>root</em> administrative user.</p>\n</blockquote>\n</aside>\n<h2>Running snap commands</h2>\n<p>A snap’s installed applications can be found under <code>/snap/bin</code>, and subsequently, often added to <em>$PATH</em>. This makes commands directly accessible from the command line.</p>\n<p>For example, the command installed via the VLC snap is simply <em>vlc</em>:</p>\n<pre><code class="lang-bash">$ which vlc\n/snap/bin/vlc\n</code></pre>\n<p>If executing a command directly doesn’t work, try prefixing it with the <em>/snap/bin</em> path:</p>\n<pre><code class="lang-bash">$ /snap/bin/vlc\n</code></pre>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ Adding <code>/snap/bin</code> to your default <em>$PATH</em> makes running snaps that don’t automatically add themselves more convenient.</p>\n</blockquote>\n</aside>\n<h2>Listing installed snaps</h2>\n<p>Use <code>snap list</code> to show a list of snaps installed on your system:</p>\n<pre><code class="lang-bash">$ snap list\nName     Version        Rev   Tracking  Publisher   Notes\ncore     16-2.35.1      5419  beta      canonical✓  core\nspotify  1.0.88.353     19    stable    spotify✓    -\nvlc      3.0.4          555   stable    videolan✓   -\n</code></pre>\n<p>Some snaps, such as <em>core</em> listed above, are installed by automatically by snapd to satisfy the requirements of other snaps.</p>\n<h2>Refreshing an installed snap</h2>\n<p>Snaps are updated automatically. However, to manually check for updates, use the following command:</p>\n<pre><code class="lang-bash">$ sudo snap refresh vlc\n</code></pre>\n<p>The above will check the channel being tracked by the snap. If a newer version of the snap is available, it will be downloaded and installed.</p>\n<p>Changing the channel being tracked and refreshing the snap can be accomplished with a single command:</p>\n<pre><code class="lang-bash">$ sudo snap refresh --channel=beta vlc\n</code></pre>\n<p>Updates are automatically installed within 6 hours of a revision being made to a tracked channel, keeping most systems up-to-date. This schedule can be tuned via configuration options.</p>\n<h2>Versions and revisions</h2>\n<p>Versions and revisions convey different details about one specific release of a snap:</p>\n<ul>\n<li>\n<em>Version</em> : the version of the software being packaged, as assigned by the developers</li>\n<li>\n<em>Revision</em>: the sequence number assigned by the store when the snap file was uploaded</li>\n</ul>\n<p>The <em>version</em> is a string that was assigned to a project by its developers, according to their development practices. It tells the user what content to expect from a snap. The <em>revision</em> is an automatic number assigned by the Snap store, giving the snap it a unique identity within the channel.</p>\n<p>Neither the version nor the revision enforce an order of release. The local system will simply attempt to install whatever snap is recommended by the publisher in the channel being tracked.</p>\n<h2>Reverting an installed snap</h2>\n<p>A snap may be reverted to a previously used revision with the <code>snap revert</code> command:</p>\n<pre><code class="lang-bash">$ sudo snap revert vlc\n</code></pre>\n<p>This operation will revert both the snap revision and the data associated with the software. If the previously used revision of the snap is from a different channel, that snap will be installed but the channel being tracked won’t change.</p>\n<p>A snap won’t automatically be updated to a previously reverted revision. Instead, snapd will wait for a new and different revision to be made available by the publisher and then update.</p>\n<p>Reverting twice should work too. Snapd attempts to keep three revisions of a snap available: the most recently installed, plus the two previous installations.</p>\n<h2>Listing all available revisions</h2>\n<p>The following command lists all revisions available for every installed snap, and also highlights which particular revisions are disabled at the moment:</p>\n<pre><code class="lang-bash">$ snap list --all\nName   Version         Rev   Tracking  Publisher   Notes\nvlc    4.0.0-dev-4620  560   edge      videolan✓   disabled                                                                              \nvlc    3.0.4           555   edge      videolan✓   -\n</code></pre>\n<p>A previously used snap will display <em>disabled</em> in the Notes column of the output.</p>\n<p>Manually keeping track of which snap revisions available is generally unnecessary. A single revision will only ever be in use at a time, and snapd will remove old revisions automatically.</p>\n<h2>Enabling and disabling snaps</h2>\n<p>If a snaps is temporarily undesired, it can be disabled and later enabled again. This avoids having to remove and reinstall them in the system:</p>\n<pre><code class="lang-bash">$ sudo snap disable vlc\nvlc disabled\n\n$ sudo snap enable vlc\nvlc enabled\n</code></pre>\n<h2>Where to go next</h2>\n<ul>\n<li><a href="/t/channels/551">Channels</a></li>\n<li><a href="/t/commands-and-aliases/3950">Commands and aliases</a></li>\n<li><a href="/t/service-management/3965">Service management</a></li>\n<li>Interface management <em>(work in progress)</em>\n</li>\n<li>Changes and tasks <em>(work in progress)</em>\n</li>\n<li><a href="/t/configuration-in-snaps/510">Configuration in snaps</a></li>\n<li>Looking inside snaps <em>(work in progress)</em>\n</li>\n</ul>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2018-09-12T12:28:50.410Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 42,
                        "incoming_link_count": 78,
                        "reads": 41,
                        "score": 360.3,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Wiki Content",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 34,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                                "internal": True,
                                "reflection": False,
                                "title": "Configuration in snaps",
                                "clicks": 11,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/channels/551",
                                "internal": True,
                                "reflection": False,
                                "title": "Channels",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                                "internal": True,
                                "reflection": False,
                                "title": "Commands and aliases",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/service-management/3965",
                                "internal": True,
                                "reflection": False,
                                "title": "Service management",
                                "clicks": 2,
                            },
                            {
                                "url": "https://snapcraft.io/store",
                                "internal": False,
                                "reflection": False,
                                "title": "Install Linux apps in seconds | Snap Store",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/installing-snapd/6735",
                                "internal": True,
                                "reflection": False,
                                "title": "Installing snapd",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/documentation-outline/3781",
                                "internal": True,
                                "reflection": True,
                                "title": "Documentation outline",
                                "clicks": 3,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 1044,
                        "hidden": False,
                        "trust_level": 1,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": True,
                        "last_wiki_edit": "2018-09-12T12:28:50.505Z",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19157,
                        "name": "Thomi",
                        "username": "thomir",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        "created_at": "2018-02-06T02:02:36.430Z",
                        "cooked": '<p>Nice doc <img src="https://forum.snapcraft.io/images/emoji/emoji_one/smiley.png?v=5" title=":smiley:" class="emoji" alt=":smiley:"></p>\n<p>A couple of the examples are missing the snap name - for example:</p>\n<p><code>$ snap switch --channel=stable</code></p>\n<p>…should surely be:</p>\n<p><code>$ snap switch --channel=stable vlc</code> ?</p>\n<p>Similarly:</p>\n<p><code>$ snap refresh --channel=candidate</code></p>\n<p>Regards,</p>',
                        "post_number": 2,
                        "post_type": 1,
                        "updated_at": "2018-02-06T02:02:36.430Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 10,
                        "incoming_link_count": 0,
                        "reads": 28,
                        "score": 55.9,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Thomi",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 85,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19158,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-06T02:04:18.224Z",
                        "cooked": "<p>Thanks! … and fixed!</p>",
                        "post_number": 3,
                        "post_type": 1,
                        "updated_at": "2018-02-06T02:04:18.224Z",
                        "reply_count": 0,
                        "reply_to_post_number": 2,
                        "quote_count": 0,
                        "avg_time": 11,
                        "incoming_link_count": 0,
                        "reads": 22,
                        "score": 4.75,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "thomir",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19333,
                        "name": "Simos",
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "created_at": "2018-02-08T01:33:14.958Z",
                        "cooked": "<p>Great guide.<br>\nI am wondering whether “sudo” is needed when trying to install a snap.<br>\nIf you are running a distro in a virtualized environment, then you need “sudo snap”. Otherwise, you do not.</p>\n<p>Is that the case?</p>",
                        "post_number": 4,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:33:14.958Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 13,
                        "incoming_link_count": 0,
                        "reads": 16,
                        "score": 8.65,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Simos",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 31,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19334,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-08T01:37:45.052Z",
                        "cooked": "<p>I’m not sure I get your question, so please correct me if I’m on the wrong track.</p>\n<p>The sudo is needed because in general it seems nice to assume people are not running all commands as root, but instead as their usual user, so the sudo increases the privilege of the command following it to that of the system administrator. That said, when running commands inside a lxd container or similar, the root is more also more isolated and thus more natural, so you might not need it.</p>",
                        "post_number": 5,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:37:45.052Z",
                        "reply_count": 1,
                        "reply_to_post_number": 4,
                        "quote_count": 0,
                        "avg_time": 12,
                        "incoming_link_count": 0,
                        "reads": 17,
                        "score": 8.8,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "simos",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19337,
                        "name": "Simos",
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "created_at": "2018-02-08T01:50:51.563Z",
                        "cooked": '<p>I posted a dedicated question at <a href="https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909">"sudo snap install" or just "snap install"?</a></p>\n<p><em>(moderation: further content dropped so we move the conversation to your topic)</em></p>',
                        "post_number": 6,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:53:14.817Z",
                        "reply_count": 0,
                        "reply_to_post_number": 5,
                        "quote_count": 0,
                        "avg_time": 9,
                        "incoming_link_count": 0,
                        "reads": 17,
                        "score": 3.65,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Simos",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 2,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909",
                                "internal": True,
                                "reflection": False,
                                "title": '"sudo snap install" or just "snap install"?',
                                "clicks": 4,
                            }
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 31,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                ],
                "stream": [19156, 19157, 19158, 19333, 19334, 19337],
            },
            "timeline_lookup": [[1, 225], [4, 223]],
            "suggested_topics": [
                {
                    "id": 5124,
                    "title": "Snapcraft plugin API",
                    "fancy_title": "Snapcraft plugin API",
                    "slug": "snapcraft-plugin-api",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-04-24T21:11:53.324Z",
                    "last_posted_at": "2018-04-24T21:11:53.421Z",
                    "bumped": True,
                    "bumped_at": "2018-04-24T22:21:14.827Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 184,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 17,
                                "username": "kyrofa",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/kyrofa/{size}/685_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 6754,
                    "title": "Installing snap on Raspbian",
                    "fancy_title": "Installing snap on Raspbian",
                    "slug": "installing-snap-on-raspbian",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-09T10:08:27.411Z",
                    "last_posted_at": "2018-08-09T10:08:27.553Z",
                    "bumped": True,
                    "bumped_at": "2018-09-19T09:10:31.949Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 75,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 3781,
                    "title": "Documentation outline",
                    "fancy_title": "Documentation outline",
                    "slug": "documentation-outline",
                    "posts_count": 14,
                    "reply_count": 8,
                    "highest_post_number": 14,
                    "image_url": None,
                    "created_at": "2018-01-31T01:35:55.823Z",
                    "last_posted_at": "2018-09-14T12:27:07.940Z",
                    "bumped": True,
                    "bumped_at": "2018-09-14T12:27:07.940Z",
                    "unseen": False,
                    "pinned": True,
                    "unpinned": None,
                    "excerpt": "This is the experimental snap, snapd, and snapcraft documentation that is being worked on to eventually become the main source of information about how to use and publish snaps, and how to develop the tools around them. \n&hellip;",
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 12,
                    "views": 1621,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 1,
                                "username": "niemeyer",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 286,
                                "username": "daniel",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 898,
                                "username": "nottrobin",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 4370,
                    "title": "Adopt info from other metadata sources",
                    "fancy_title": "Adopt info from other metadata sources",
                    "slug": "adopt-info-from-other-metadata-sources",
                    "posts_count": 4,
                    "reply_count": 0,
                    "highest_post_number": 4,
                    "image_url": None,
                    "created_at": "2018-03-07T09:11:24.069Z",
                    "last_posted_at": "2018-06-26T11:10:27.005Z",
                    "bumped": True,
                    "bumped_at": "2018-06-26T11:10:27.005Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 3,
                    "views": 245,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 22,
                                "username": "elopio",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/elopio/{size}/36_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 25,
                                "username": "sergiusens",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sergiusens/{size}/40_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 67,
                                "username": "sitter",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sitter/{size}/90_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 1417,
                                "username": "Lin-Buo-Ren",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6759,
                    "title": "Testing the snap from Mac",
                    "fancy_title": "Testing the snap from Mac",
                    "slug": "testing-the-snap-from-mac",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-09T12:38:10.267Z",
                    "last_posted_at": "2018-08-09T12:38:10.425Z",
                    "bumped": True,
                    "bumped_at": "2018-08-10T14:14:51.535Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 75,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 12,
                                "username": "evan",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 3876,
            "title": "Getting started",
            "fancy_title": "Getting started",
            "posts_count": 6,
            "created_at": "2018-02-06T01:44:42.363Z",
            "views": 784,
            "reply_count": 3,
            "like_count": 1,
            "last_posted_at": "2018-02-08T01:50:51.563Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "getting-started",
            "category_id": 15,
            "word_count": 1397,
            "deleted_at": None,
            "user_id": 1044,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": None,
            "pinned_until": None,
            "draft": None,
            "draft_key": "topic_3876",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": False,
            "details": {
                "created_by": {
                    "id": 1044,
                    "username": "wiki",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                },
                "last_poster": {
                    "id": 31,
                    "username": "simos",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                },
                "participants": [
                    {
                        "id": 1,
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 31,
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 85,
                        "username": "thomir",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1044,
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                        "title": "Configuration in snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 11,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/channels/551",
                        "title": "Channels",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                        "title": "Commands and aliases",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909",
                        "title": '"sudo snap install" or just "snap install"?',
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 31,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/documentation-outline/3781",
                        "title": "Documentation outline",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 3,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/service-management/3965",
                        "title": "Service management",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 2,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://snapcraft.io/store",
                        "title": "Install Linux apps in seconds | Snap Store",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/installing-snapd/6735",
                        "title": "Installing snapd",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 6,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 60,
            "participant_count": 4,
        },
        status_code=200,
        headers={
            "Date": "Wed, 19 Sep 2018 09:18:36 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "405d024e-123d-4891-a904-f9f286d3e59d",
            "X-Runtime": "0.351659",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/3876.json",
        json={
            "post_stream": {
                "posts": [
                    {
                        "id": 19156,
                        "name": "Wiki Content",
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "created_at": "2018-02-06T01:44:42.553Z",
                        "cooked": '<aside class="quote no-group">\n<blockquote>\n<p><img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"> <strong>NOTE TO EDITORS</strong> <img src="https://forum.snapcraft.io/images/emoji/emoji_one/construction.png?v=5" title=":construction:" class="emoji" alt=":construction:"></p>\n<p>This document is introductory material, and as such it is organized with a story line in mind. Each section builds upon information described in preceding sections. That also means the content is focused on foundational concepts, so it’s not a complete reference and not supposed to provide in-depth information about these aspects.</p>\n</blockquote>\n</aside>\n<p>The following sections provide a basic overview of using snaps, from their installation to their management and manipulation.</p>\n<h2>Installing  snapd</h2>\n<p>The <em>snapd</em> daemon manages the snap environment on the local system. Its installation will include the <em>snap</em> tool for interacting with snaps. You can check both are installed by attempting to run <code>snap version</code> on the command line:</p>\n<pre><code class="lang-bash">$ snap version\nsnap    2.35\nsnapd   2.35\nseries  16\nneon    16.04\nkernel  4.4.0-128-generic\n</code></pre>\n<p>If all is well, version numbers for the main system components will be output, as shown above.</p>\n<p>If the <em>snap</em> command is not found, or if the command takes a while to respond before reporting that <em>snapd is unavailable</em>, make sure <a href="/t/can-i-use-snaps/6735">snapd is properly installed</a> before continuing.</p>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ The <code>"$"</code> above represents the command line prompt. Sample commands come after this prompt with any relevant output shown below.</p>\n</blockquote>\n</aside>\n<h2>Searching for snaps</h2>\n<p>With snapd installed, snaps can be discovered, searched for, and installed  from the <a href="https://snapcraft.io/store" rel="nofollow noopener">Snap Store</a> and directly from the command line. For example, the following command returns a list of media players:</p>\n<pre><code class="lang-bash">$ snap find "media player"\nName  Version  Developer  Notes  Summary\n(...)\nvlc        3.0.4     videolan✓    -      The ultimate media player                                                                 \nmpv        0.26.0    casept       -      a free, open source, and cross-platform media player.  \n(...)\n</code></pre>\n<p>The <code>✓</code> alongside <em>videolan</em> in the above output indicates that the snap publisher has been verified.</p>\n<h2>Learning about a snap</h2>\n<p>The <em>snap info</em> command makes it easy to find more details about a specific snap. These details include what a snap does, who publishes it, the command(s) it provides and which channel versions are available for installation:</p>\n<pre><code class="lang-bash">$ snap info vlc\nname:      vlc\nsummary:   The ultimate media player\npublisher: VideoLAN✓\ncontact:   https://www.videolan.org/support/\ndescription: |\n  VLC is the VideoLAN project\'s media player.\n  (...)\nsnap-id: RT9mcUhVsRYrDLG8qnvGiy26NKvv6Qkd\ncommands:\n  - vlc\nchannels:\n  stable:    3.0.0                   (158) 197MB -\n  candidate: 3.0.0                   (158) 197MB -\n  beta:      3.0.0-5-g407d4ba        (160) 197MB -\n  edge:      4.0.0-dev-1218-g201542f (159) 197MB \n</code></pre>\n<h2>Installing a snap</h2>\n<p>Installing a snap is straightforward:</p>\n<pre><code class="lang-bash">$ sudo snap install vlc\n</code></pre>\n<p><a href="/t/channels/551">Channels</a> are an important snap concept. They define which release of a snap is installed and tracked for updates. The <em>stable</em> channel is used by default, but opting to install from a different channel is easily accomplished:</p>\n<pre><code class="lang-bash">$ sudo snap install --channel=edge vlc\n</code></pre>\n<p>After installation, the channel being tracked can be changed with:</p>\n<pre><code class="lang-bash">$ sudo snap switch --channel=stable vlc\n</code></pre>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ The <em>sudo</em> command ensures the command following it is executed as the <em>root</em> administrative user.</p>\n</blockquote>\n</aside>\n<h2>Running snap commands</h2>\n<p>A snap’s installed applications can be found under <code>/snap/bin</code>, and subsequently, often added to <em>$PATH</em>. This makes commands directly accessible from the command line.</p>\n<p>For example, the command installed via the VLC snap is simply <em>vlc</em>:</p>\n<pre><code class="lang-bash">$ which vlc\n/snap/bin/vlc\n</code></pre>\n<p>If executing a command directly doesn’t work, try prefixing it with the <em>/snap/bin</em> path:</p>\n<pre><code class="lang-bash">$ /snap/bin/vlc\n</code></pre>\n<aside class="quote no-group">\n<blockquote>\n<p>ⓘ Adding <code>/snap/bin</code> to your default <em>$PATH</em> makes running snaps that don’t automatically add themselves more convenient.</p>\n</blockquote>\n</aside>\n<h2>Listing installed snaps</h2>\n<p>Use <code>snap list</code> to show a list of snaps installed on your system:</p>\n<pre><code class="lang-bash">$ snap list\nName     Version        Rev   Tracking  Publisher   Notes\ncore     16-2.35.1      5419  beta      canonical✓  core\nspotify  1.0.88.353     19    stable    spotify✓    -\nvlc      3.0.4          555   stable    videolan✓   -\n</code></pre>\n<p>Some snaps, such as <em>core</em> listed above, are installed by automatically by snapd to satisfy the requirements of other snaps.</p>\n<h2>Refreshing an installed snap</h2>\n<p>Snaps are updated automatically. However, to manually check for updates, use the following command:</p>\n<pre><code class="lang-bash">$ sudo snap refresh vlc\n</code></pre>\n<p>The above will check the channel being tracked by the snap. If a newer version of the snap is available, it will be downloaded and installed.</p>\n<p>Changing the channel being tracked and refreshing the snap can be accomplished with a single command:</p>\n<pre><code class="lang-bash">$ sudo snap refresh --channel=beta vlc\n</code></pre>\n<p>Updates are automatically installed within 6 hours of a revision being made to a tracked channel, keeping most systems up-to-date. This schedule can be tuned via configuration options.</p>\n<h2>Versions and revisions</h2>\n<p>Versions and revisions convey different details about one specific release of a snap:</p>\n<ul>\n<li>\n<em>Version</em> : the version of the software being packaged, as assigned by the developers</li>\n<li>\n<em>Revision</em>: the sequence number assigned by the store when the snap file was uploaded</li>\n</ul>\n<p>The <em>version</em> is a string that was assigned to a project by its developers, according to their development practices. It tells the user what content to expect from a snap. The <em>revision</em> is an automatic number assigned by the Snap store, giving the snap it a unique identity within the channel.</p>\n<p>Neither the version nor the revision enforce an order of release. The local system will simply attempt to install whatever snap is recommended by the publisher in the channel being tracked.</p>\n<h2>Reverting an installed snap</h2>\n<p>A snap may be reverted to a previously used revision with the <code>snap revert</code> command:</p>\n<pre><code class="lang-bash">$ sudo snap revert vlc\n</code></pre>\n<p>This operation will revert both the snap revision and the data associated with the software. If the previously used revision of the snap is from a different channel, that snap will be installed but the channel being tracked won’t change.</p>\n<p>A snap won’t automatically be updated to a previously reverted revision. Instead, snapd will wait for a new and different revision to be made available by the publisher and then update.</p>\n<p>Reverting twice should work too. Snapd attempts to keep three revisions of a snap available: the most recently installed, plus the two previous installations.</p>\n<h2>Listing all available revisions</h2>\n<p>The following command lists all revisions available for every installed snap, and also highlights which particular revisions are disabled at the moment:</p>\n<pre><code class="lang-bash">$ snap list --all\nName   Version         Rev   Tracking  Publisher   Notes\nvlc    4.0.0-dev-4620  560   edge      videolan✓   disabled                                                                              \nvlc    3.0.4           555   edge      videolan✓   -\n</code></pre>\n<p>A previously used snap will display <em>disabled</em> in the Notes column of the output.</p>\n<p>Manually keeping track of which snap revisions available is generally unnecessary. A single revision will only ever be in use at a time, and snapd will remove old revisions automatically.</p>\n<h2>Enabling and disabling snaps</h2>\n<p>If a snaps is temporarily undesired, it can be disabled and later enabled again. This avoids having to remove and reinstall them in the system:</p>\n<pre><code class="lang-bash">$ sudo snap disable vlc\nvlc disabled\n\n$ sudo snap enable vlc\nvlc enabled\n</code></pre>\n<h2>Where to go next</h2>\n<ul>\n<li><a href="/t/channels/551">Channels</a></li>\n<li><a href="/t/commands-and-aliases/3950">Commands and aliases</a></li>\n<li><a href="/t/service-management/3965">Service management</a></li>\n<li>Interface management <em>(work in progress)</em>\n</li>\n<li>Changes and tasks <em>(work in progress)</em>\n</li>\n<li><a href="/t/configuration-in-snaps/510">Configuration in snaps</a></li>\n<li>Looking inside snaps <em>(work in progress)</em>\n</li>\n</ul>',
                        "post_number": 1,
                        "post_type": 1,
                        "updated_at": "2018-09-12T12:28:50.410Z",
                        "reply_count": 0,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 42,
                        "incoming_link_count": 78,
                        "reads": 41,
                        "score": 360.3,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Wiki Content",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 34,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                                "internal": True,
                                "reflection": False,
                                "title": "Configuration in snaps",
                                "clicks": 11,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/channels/551",
                                "internal": True,
                                "reflection": False,
                                "title": "Channels",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                                "internal": True,
                                "reflection": False,
                                "title": "Commands and aliases",
                                "clicks": 9,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/service-management/3965",
                                "internal": True,
                                "reflection": False,
                                "title": "Service management",
                                "clicks": 2,
                            },
                            {
                                "url": "https://snapcraft.io/store",
                                "internal": False,
                                "reflection": False,
                                "title": "Install Linux apps in seconds | Snap Store",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/installing-snapd/6735",
                                "internal": True,
                                "reflection": False,
                                "title": "Installing snapd",
                                "clicks": 0,
                            },
                            {
                                "url": "https://forum.snapcraft.io/t/documentation-outline/3781",
                                "internal": True,
                                "reflection": True,
                                "title": "Documentation outline",
                                "clicks": 3,
                            },
                        ],
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 1044,
                        "hidden": False,
                        "trust_level": 1,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": True,
                        "last_wiki_edit": "2018-09-12T12:28:50.505Z",
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19157,
                        "name": "Thomi",
                        "username": "thomir",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        "created_at": "2018-02-06T02:02:36.430Z",
                        "cooked": '<p>Nice doc <img src="https://forum.snapcraft.io/images/emoji/emoji_one/smiley.png?v=5" title=":smiley:" class="emoji" alt=":smiley:"></p>\n<p>A couple of the examples are missing the snap name - for example:</p>\n<p><code>$ snap switch --channel=stable</code></p>\n<p>…should surely be:</p>\n<p><code>$ snap switch --channel=stable vlc</code> ?</p>\n<p>Similarly:</p>\n<p><code>$ snap refresh --channel=candidate</code></p>\n<p>Regards,</p>',
                        "post_number": 2,
                        "post_type": 1,
                        "updated_at": "2018-02-06T02:02:36.430Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 10,
                        "incoming_link_count": 0,
                        "reads": 28,
                        "score": 55.9,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Thomi",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [{"id": 2, "count": 1}],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 85,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19158,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-06T02:04:18.224Z",
                        "cooked": "<p>Thanks! … and fixed!</p>",
                        "post_number": 3,
                        "post_type": 1,
                        "updated_at": "2018-02-06T02:04:18.224Z",
                        "reply_count": 0,
                        "reply_to_post_number": 2,
                        "quote_count": 0,
                        "avg_time": 11,
                        "incoming_link_count": 0,
                        "reads": 22,
                        "score": 4.75,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "thomir",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19333,
                        "name": "Simos",
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "created_at": "2018-02-08T01:33:14.958Z",
                        "cooked": "<p>Great guide.<br>\nI am wondering whether “sudo” is needed when trying to install a snap.<br>\nIf you are running a distro in a virtualized environment, then you need “sudo snap”. Otherwise, you do not.</p>\n<p>Is that the case?</p>",
                        "post_number": 4,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:33:14.958Z",
                        "reply_count": 1,
                        "reply_to_post_number": None,
                        "quote_count": 0,
                        "avg_time": 13,
                        "incoming_link_count": 0,
                        "reads": 16,
                        "score": 8.65,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Simos",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 31,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19334,
                        "name": "Gustavo Niemeyer",
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "created_at": "2018-02-08T01:37:45.052Z",
                        "cooked": "<p>I’m not sure I get your question, so please correct me if I’m on the wrong track.</p>\n<p>The sudo is needed because in general it seems nice to assume people are not running all commands as root, but instead as their usual user, so the sudo increases the privilege of the command following it to that of the system administrator. That said, when running commands inside a lxd container or similar, the root is more also more isolated and thus more natural, so you might not need it.</p>",
                        "post_number": 5,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:37:45.052Z",
                        "reply_count": 1,
                        "reply_to_post_number": 4,
                        "quote_count": 0,
                        "avg_time": 12,
                        "incoming_link_count": 0,
                        "reads": 17,
                        "score": 8.8,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Gustavo Niemeyer",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 1,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "simos",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": True,
                        "staff": True,
                        "user_id": 1,
                        "hidden": False,
                        "trust_level": 3,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                    {
                        "id": 19337,
                        "name": "Simos",
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "created_at": "2018-02-08T01:50:51.563Z",
                        "cooked": '<p>I posted a dedicated question at <a href="https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909">"sudo snap install" or just "snap install"?</a></p>\n<p><em>(moderation: further content dropped so we move the conversation to your topic)</em></p>',
                        "post_number": 6,
                        "post_type": 1,
                        "updated_at": "2018-02-08T01:53:14.817Z",
                        "reply_count": 0,
                        "reply_to_post_number": 5,
                        "quote_count": 0,
                        "avg_time": 9,
                        "incoming_link_count": 0,
                        "reads": 17,
                        "score": 3.65,
                        "yours": False,
                        "topic_id": 3876,
                        "topic_slug": "getting-started",
                        "display_username": "Simos",
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_bg_color": None,
                        "primary_group_flair_color": None,
                        "version": 2,
                        "can_edit": False,
                        "can_delete": False,
                        "can_recover": False,
                        "can_wiki": False,
                        "link_counts": [
                            {
                                "url": "https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909",
                                "internal": True,
                                "reflection": False,
                                "title": '"sudo snap install" or just "snap install"?',
                                "clicks": 4,
                            }
                        ],
                        "read": True,
                        "user_title": None,
                        "reply_to_user": {
                            "username": "niemeyer",
                            "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        },
                        "actions_summary": [],
                        "moderator": False,
                        "admin": False,
                        "staff": False,
                        "user_id": 31,
                        "hidden": False,
                        "trust_level": 2,
                        "deleted_at": None,
                        "user_deleted": False,
                        "edit_reason": None,
                        "can_view_edit_history": True,
                        "wiki": False,
                        "can_accept_answer": False,
                        "can_unaccept_answer": False,
                        "accepted_answer": False,
                    },
                ],
                "stream": [19156, 19157, 19158, 19333, 19334, 19337],
            },
            "timeline_lookup": [[1, 225], [4, 223]],
            "suggested_topics": [
                {
                    "id": 5124,
                    "title": "Snapcraft plugin API",
                    "fancy_title": "Snapcraft plugin API",
                    "slug": "snapcraft-plugin-api",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-04-24T21:11:53.324Z",
                    "last_posted_at": "2018-04-24T21:11:53.421Z",
                    "bumped": True,
                    "bumped_at": "2018-04-24T22:21:14.827Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 1,
                    "views": 184,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 17,
                                "username": "kyrofa",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/kyrofa/{size}/685_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 6754,
                    "title": "Installing snap on Raspbian",
                    "fancy_title": "Installing snap on Raspbian",
                    "slug": "installing-snap-on-raspbian",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-09T10:08:27.411Z",
                    "last_posted_at": "2018-08-09T10:08:27.553Z",
                    "bumped": True,
                    "bumped_at": "2018-09-19T09:10:31.949Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 75,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        }
                    ],
                },
                {
                    "id": 3781,
                    "title": "Documentation outline",
                    "fancy_title": "Documentation outline",
                    "slug": "documentation-outline",
                    "posts_count": 14,
                    "reply_count": 8,
                    "highest_post_number": 14,
                    "image_url": None,
                    "created_at": "2018-01-31T01:35:55.823Z",
                    "last_posted_at": "2018-09-14T12:27:07.940Z",
                    "bumped": True,
                    "bumped_at": "2018-09-14T12:27:07.940Z",
                    "unseen": False,
                    "pinned": True,
                    "unpinned": None,
                    "excerpt": "This is the experimental snap, snapd, and snapcraft documentation that is being worked on to eventually become the main source of information about how to use and publish snaps, and how to develop the tools around them. \n&hellip;",
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 12,
                    "views": 1621,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 2772,
                                "username": "degville",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/degville/{size}/2021_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 1,
                                "username": "niemeyer",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 286,
                                "username": "daniel",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/daniel/{size}/2043_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 898,
                                "username": "nottrobin",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/n/e0b2c6/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 4370,
                    "title": "Adopt info from other metadata sources",
                    "fancy_title": "Adopt info from other metadata sources",
                    "slug": "adopt-info-from-other-metadata-sources",
                    "posts_count": 4,
                    "reply_count": 0,
                    "highest_post_number": 4,
                    "image_url": None,
                    "created_at": "2018-03-07T09:11:24.069Z",
                    "last_posted_at": "2018-06-26T11:10:27.005Z",
                    "bumped": True,
                    "bumped_at": "2018-06-26T11:10:27.005Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 3,
                    "views": 245,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": None,
                            "description": "Original Poster",
                            "user": {
                                "id": 22,
                                "username": "elopio",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/elopio/{size}/36_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 25,
                                "username": "sergiusens",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sergiusens/{size}/40_1.png",
                            },
                        },
                        {
                            "extras": None,
                            "description": "Frequent Poster",
                            "user": {
                                "id": 67,
                                "username": "sitter",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/sitter/{size}/90_1.png",
                            },
                        },
                        {
                            "extras": "latest",
                            "description": "Most Recent Poster",
                            "user": {
                                "id": 1417,
                                "username": "Lin-Buo-Ren",
                                "avatar_template": "/letter_avatar_proxy/v2/letter/l/ebca7d/{size}.png",
                            },
                        },
                    ],
                },
                {
                    "id": 6759,
                    "title": "Testing the snap from Mac",
                    "fancy_title": "Testing the snap from Mac",
                    "slug": "testing-the-snap-from-mac",
                    "posts_count": 1,
                    "reply_count": 0,
                    "highest_post_number": 1,
                    "image_url": None,
                    "created_at": "2018-08-09T12:38:10.267Z",
                    "last_posted_at": "2018-08-09T12:38:10.425Z",
                    "bumped": True,
                    "bumped_at": "2018-08-10T14:14:51.535Z",
                    "unseen": False,
                    "pinned": False,
                    "unpinned": None,
                    "visible": True,
                    "closed": False,
                    "archived": False,
                    "bookmarked": None,
                    "liked": None,
                    "tags": [],
                    "archetype": "regular",
                    "like_count": 0,
                    "views": 75,
                    "category_id": 15,
                    "featured_link": None,
                    "posters": [
                        {
                            "extras": "latest single",
                            "description": "Original Poster, Most Recent Poster",
                            "user": {
                                "id": 12,
                                "username": "evan",
                                "avatar_template": "/user_avatar/forum.snapcraft.io/evan/{size}/28_1.png",
                            },
                        }
                    ],
                },
            ],
            "tags": [],
            "id": 3876,
            "title": "Getting started",
            "fancy_title": "Getting started",
            "posts_count": 6,
            "created_at": "2018-02-06T01:44:42.363Z",
            "views": 784,
            "reply_count": 3,
            "like_count": 1,
            "last_posted_at": "2018-02-08T01:50:51.563Z",
            "visible": True,
            "closed": False,
            "archived": False,
            "has_summary": False,
            "archetype": "regular",
            "slug": "getting-started",
            "category_id": 15,
            "word_count": 1397,
            "deleted_at": None,
            "user_id": 1044,
            "featured_link": None,
            "pinned_globally": False,
            "pinned_at": None,
            "pinned_until": None,
            "draft": None,
            "draft_key": "topic_3876",
            "draft_sequence": None,
            "unpinned": None,
            "pinned": False,
            "details": {
                "created_by": {
                    "id": 1044,
                    "username": "wiki",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                },
                "last_poster": {
                    "id": 31,
                    "username": "simos",
                    "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                },
                "participants": [
                    {
                        "id": 1,
                        "username": "niemeyer",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/niemeyer/{size}/13_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 31,
                        "username": "simos",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/simos/{size}/50_1.png",
                        "post_count": 2,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 85,
                        "username": "thomir",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/thomir/{size}/102_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                    {
                        "id": 1044,
                        "username": "wiki",
                        "avatar_template": "/user_avatar/forum.snapcraft.io/wiki/{size}/425_1.png",
                        "post_count": 1,
                        "primary_group_name": None,
                        "primary_group_flair_url": None,
                        "primary_group_flair_color": None,
                        "primary_group_flair_bg_color": None,
                    },
                ],
                "links": [
                    {
                        "url": "https://forum.snapcraft.io/t/configuration-in-snaps/510",
                        "title": "Configuration in snaps",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 11,
                        "user_id": 1,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/channels/551",
                        "title": "Channels",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/commands-and-aliases/3950",
                        "title": "Commands and aliases",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 9,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/sudo-snap-install-or-just-snap-install/3909",
                        "title": '"sudo snap install" or just "snap install"?',
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 4,
                        "user_id": 31,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/documentation-outline/3781",
                        "title": "Documentation outline",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 3,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/service-management/3965",
                        "title": "Service management",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 2,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://snapcraft.io/store",
                        "title": "Install Linux apps in seconds | Snap Store",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                    {
                        "url": "https://forum.snapcraft.io/t/installing-snapd/6735",
                        "title": "Installing snapd",
                        "fancy_title": None,
                        "internal": False,
                        "attachment": False,
                        "reflection": False,
                        "clicks": 0,
                        "user_id": 1044,
                        "domain": "forum.snapcraft.io",
                        "root_domain": "snapcraft.io",
                    },
                ],
                "notification_level": 1,
                "can_flag_topic": False,
            },
            "current_post_number": 1,
            "highest_post_number": 6,
            "deleted_by": None,
            "actions_summary": [
                {"id": 4, "count": 0, "hidden": False, "can_act": False},
                {"id": 8, "count": 0, "hidden": False, "can_act": False},
                {"id": 7, "count": 0, "hidden": False, "can_act": False},
            ],
            "chunk_size": 20,
            "bookmarked": None,
            "topic_timer": None,
            "message_bus_last_id": 60,
            "participant_count": 4,
        },
        status_code=200,
        headers={
            "Date": "Wed, 19 Sep 2018 09:18:36 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "application/json; charset=utf-8",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "X-Request-Id": "405d024e-123d-4891-a904-f9f286d3e59d",
            "X-Runtime": "0.351659",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/configuration-options/87.json",
        text='<html><body>You are being <a href="https://forum.snapcraft.io/t/system-options/87.json">redirected</a>.</body></html>',
        status_code=301,
        headers={
            "Date": "Wed, 19 Sep 2018 09:36:02 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Location": "https://forum.snapcraft.io/t/system-options/87.json",
            "Cache-Control": "no-store, must-revalidate, no-cache, private",
            "Content-Type": "text/html; charset=utf-8",
            "X-Request-Id": "73fd2625-e180-4cd3-b17f-b9ab7b77d797",
            "X-Runtime": "0.052193",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
    adapter.register_uri(
        "GET",
        "https://forum.snapcraft.io/t/fictional-document.json",
        text=(
            """<h1 class="page-not-found">Oops! That page doesn’t exist or is private.</h1>
    <div class="row page-not-found-topics">
        <div class="popular-topics">
        <h2 class="popular-topics-title">Popular</h2>
            <div class='not-found-topic'>
            <a href="/t/windows95-snap/7059">Windows95 snap</a><a class='badge-wrapper  box' href='/c/snap'><span class='badge-category-bg' style='background-color: #92278F;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Threads discussing details of particular snaps.'>snap</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/developer-sprint-sep-17th-2018/7336">Developer sprint Sep 17th, 2018</a><a class='badge-wrapper  box' href='/c/snapd'><span class='badge-category-bg' style='background-color: #0E76BD;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='This is the place for all things snapd, the daemon that handles snaps. We have a few subcategories, but feel free to just use the main one when in doubt.'>snapd</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/the-future-of-the-docker-snap/7218">The Future of the Docker Snap</a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/core18-included-binaries/7191">Core18 included binaries</a><a class='badge-wrapper  box' href='/c/device'><span class='badge-category-bg' style='background-color: #231F20;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Conversations about creation and maintenance of images which leverage snapd.'>device</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/call-for-testing-snapcraft-2-43/7024">Call for testing: snapcraft 2.43</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/can-not-start-service/7096">Can not start service</a><a class='badge-wrapper  box' href='/c/snapd'><span class='badge-category-bg' style='background-color: #0E76BD;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='This is the place for all things snapd, the daemon that handles snaps. We have a few subcategories, but feel free to just use the main one when in doubt.'>snapd</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/permission-denied-when-building-with-snapcore-snapcraft/7186">Permission denied when building with snapcore/snapcraft</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/thunderbird-version/7146">Thunderbird version</a><a class='badge-wrapper  box' href='/c/snap'><span class='badge-category-bg' style='background-color: #92278F;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Threads discussing details of particular snaps.'>snap</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/problem-launching-qt-snaps-in-wayland/7055">Problem launching QT snaps in Wayland</a><a class='badge-wrapper  box' href='/c/snap'><span class='badge-category-bg' style='background-color: #92278F;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Threads discussing details of particular snaps.'>snap</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/application-icon-doesnt-work-in-the-launcher/7292">Application icon doesn&#39;t work in the launcher</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
        <a href="/top" class="btn">More&hellip;</a>
        </div>
        <div class="recent-topics">
        <h2 class="recent-topics-title">Recent</h2>
            <div class='not-found-topic'>
            <a href="/t/arguments-accepted-by-the-application/7455">Arguments accepted by the application</a><a class='badge-wrapper  box' href='/c/snap'><span class='badge-category-bg' style='background-color: #92278F;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Threads discussing details of particular snaps.'>snap</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/updating-snapd-in-debian-unstable/7454">Updating snapd in debian unstable</a><a class='badge-wrapper  box' href='/c/snapd'><span class='badge-category-bg' style='background-color: #0E76BD;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='This is the place for all things snapd, the daemon that handles snaps. We have a few subcategories, but feel free to just use the main one when in doubt.'>snapd</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/docker-snap-status/7451">Docker Snap Status</a><a class='badge-wrapper  box' href='/c/snap'><span class='badge-category-bg' style='background-color: #92278F;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Threads discussing details of particular snaps.'>snap</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/errors-when-building-via-launchpad/7448">Errors when building via launchpad</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/libc6-in-stage-packages/7447">Libc6 in stage-packages</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/start-and-stop-for-service/7446">Start and stop for service</a><a class='badge-wrapper  box' href='/c/snapcraft'><span class='badge-category-bg' style='background-color: #F7941D;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='The snapcraft category holds discussions about the snapcraft software and the building side of snaps in general.'>snapcraft</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/public-snap-not-found-in-store/7445">Public snap not found in store</a><a class='badge-wrapper  box' href='/c/store'><span class='badge-category-bg' style='background-color: #3AB54A;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Topics related to the snap store – the server that holds snaps for distribution.'>store</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/ability-to-install-from-a-snap-package-another-snap-package/7444">Ability to install from a snap package another snap package</a><a class='badge-wrapper  box' href='/c/snapd'><span class='badge-category-bg' style='background-color: #0E76BD;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='This is the place for all things snapd, the daemon that handles snaps. We have a few subcategories, but feel free to just use the main one when in doubt.'>snapd</span></a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/the-operating-mechanism-of-a-snap-app/7443">The Operating mechanism of a snap app</a>
            </div>
            <div class='not-found-topic'>
            <a href="/t/how-to-become-verified-publisher/7442">How to become &#39;Verified&#39; publisher?</a><a class='badge-wrapper  box' href='/c/store'><span class='badge-category-bg' style='background-color: #3AB54A;'></span><span style='color: #FFFFFF' data-drop-close='true' class='badge-category clear-badge'
                    title='Topics related to the snap store – the server that holds snaps for distribution.'>store</span></a>
            </div>
        <a href="/latest" class="btn">More&hellip;</a>
        </div>
    </div>


    <div class="row">
        <div class="page-not-found-search">
        <h2>Search this site</h2>
        <p>
            <form action='//google.com/search' id='google-search'>
            <input type="text" name="q" value="fictional document">
            <input type='hidden' name="as_sitesearch" value="https://forum.snapcraft.io">
            <button class="btn btn-primary">Google</button>
            </form>
        </p>
        </div>
    </div>

    <script language="Javascript">
        window.onpopstate = function(event) {
        if (event.state && !window.hasOwnProperty("Discourse")) {  //check if Discourse object exists if not take care of back navigation
            window.location = document.location;
        }
        };
    </script>
    """
        ),
        status_code=404,
        headers={
            "Date": "Thu, 20 Sep 2018 10:11:28 GMT",
            "Server": "Apache/2.4.29 (Ubuntu)",
            "X-Frame-Options": "SAMEORIGIN",
            "X-XSS-Protection": "1; mode=block",
            "X-Content-Type-Options": "nosniff",
            "X-Discourse-Route": "topics/show",
            "Content-Type": "text/html; charset=utf-8",
            "X-Request-Id": "585fb3d4-8017-4522-af77-b3e939a6c0f1",
            "X-Runtime": "0.173561",
            "Keep-Alive": "timeout=5, max=100",
            "Connection": "Keep-Alive",
            "Transfer-Encoding": "chunked",
        },
    )
